#!/bin/csh -f
#
# PBO Shell script for processing campdement results from CWU and NMT/BSL ACs
#
# See if arguments passed
if( $#argv == 0 ) then
   grep '^## ' $0 | awk '{print substr($0,3)}'
# Here are the options
## Usage: PBO_campd.cmd <options> 
## where the following options are avaiable
##  -d yr day  where yr and day are to processed e.g. 1997 153
##  -r day     where day is number of days before current date
##  -m mailto  will invoke summary generation and sending of summary email 
##  -ldm       Pur results into LDM queue
##  -no_hfupd    Don't run hfupd to check site meta data
##  -clear       Clears Binary hfiles and previous log and start again
##
## Script run from <proc_dir>/control directory
##
   exit

endif
setenv INSTITUTE MIT
# Now set up defaults
set hfupd     = 'Y'
set clear     = 'N'
set mailto    = 'N'
set ldm       = 'N'
set srcd = '/data30/ftp/pub/incoming/ACC_PBO/'
#
# Now read the arguments
foreach a ($argv)
switch($a)
    case -d:
        set yr = $argv[2]
        set doy = $argv[3]

#       Get the gpsweek
        set jd   = `doy $yr $doy | tail -3 | head -1 | awk '{print $8}'`
        set gpsw = `doy $jd | tail -2 | head -1 | awk '{print $3}'`
        set gpsd = `doy $jd | tail -2 | head -1 | awk '{print substr($7,1,1)}'`
        set yr   = `doy $jd | tail -3 | head -1 | awk '{print substr($2,1,4)}'`
        set yr2  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,3,2)}'`
        set mth  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,6,2)}'`
        set dom  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,9,2)}'`
        set doy  = `doy $jd | tail -3 | head -1 | awk '{print $6}'`
        set mjd  = `doy $yr $doy | tail -3 | head -1 |awk '{print int($10)}'`
        set jdn  = `doy | tail -3 | head -1 | awk '{print int($10)}'`
        @ dd = $jdn - $mjd
        breaksw
    case -r:
        set dd = $argv[2]

#       Now get the day number to process
        set jd = `doy | tail -3 | head -1 | awk '{print int($10)}'`
        @ jd = $jd - $dd
        set gpsw = `doy $jd | tail -2 | head -1 | awk '{print $3}'`
        set gpsd = `doy $jd | tail -2 | head -1 | awk '{print substr($7,1,1)}'`
        set yr   = `doy $jd | tail -3 | head -1 | awk '{print substr($2,1,4)}'`
        set yr2  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,3,2)}'`
        set mth  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,6,2)}'`
        set dom  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,9,2)}'`
        set doy  = `doy $jd | tail -3 | head -1 | awk '{print $6}'`
       
        breaksw
    case -no_h*:
        set hfupd = "N"
        breaksw
    case -cl*:
        set clear = "Y"
        breaksw
    case -m*:
        set mailto = $argv[2]
        breaksw
    case -ldm:
        set ldm = "Y"
        breaksw
    default:
#       echo Unknown option $a
#       grep '^## ' $0 | awk '{print substr($0,3)}'
#       exit

endsw
shift
end

# Adjust the $gpsw
set gpsw = `echo $gpsw | awk '{printf("%04d",$1)}'`
set doy = `echo $doy | awk '{printf("%03d",$1)}'`
# Set up the log file
set logf = PBO_CAM_${gpsw}${gpsd}.log
if( $clear == "Y" ) then
   \rm $logf >&! /dev/null
   \rm ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.d.gls >&! /dev/null
   \rm ../BSL_glbf/h${gpsw}${gpsd}_1200_bsl.d.gls >&! /dev/null
   \rm ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.d.gls >&! /dev/null

   if( -e ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx.gz ) then
       \rm ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx
   endif
   if( -e ${srcd}/BSL/bsl${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx.gz ) then
       \rm ../BSL_snx/bsl${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx
   endif
   if( -e ${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx ) then
       \rm ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx
   endif
#  For CWU check if they have a supplemental as will
   if( -e ${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.c.snx ) then
      \rm ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.c.snx
      \rm ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.c.gls >&! /dev/null
   endif

endif
if( ! -e $logf  ) then
   touch $logf
endif
echo "Creating/Updating $logf"
echo "--------------------------------------------------" >> $logf
echo -n "++ LOG UPDATE ++ " >> $logf
date >> $logf
echo "--------------------------------------------------" >> $logf

#
# See if NMT file is already in glbf area
if ( ! -e ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.d.gls ) then
#   See if already in sinex area
    if( ! -e ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx ) then
        if ( -e ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx ) then 
            \mv ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx ../NMT_snx
            \mv ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.d.rms ../NMT_snx
            \mv ${srcd}/NMT/H${yr2}${mth}${dom}_nmtdr.GLX ../NMT_glbf
        else if ( -e ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx.gz ) then 
            \mv ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx.gz ../NMT_snx
             gzip -d ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx.gz
            \mv ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.d.rms ../NMT_snx
            \mv ${srcd}/NMT/H${yr2}${mth}${dom}_nmtdr.GLX ../NMT_glbf
        else
            echo "${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx not available" >>  $logf
            exit
        endif
    endif 
    if( -e ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx ) then
#       Convert the sinex to globk binary hfile
        htoglb ../NMT_glbf/ ' ' -n=GPSW -f=nmt.d -d=tr -e -m=1024 ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx >>  $logf
    endif
endif
#
# See if the CWU file is available
if ( ! -e ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.d.gls ) then
#   See if already in sinex area
    if( ! -e ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx ) then
        if ( -e ${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx ) then 
            \mv ${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx ../CWU_snx
            \mv ${srcd}/CWU/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.d.rms ../CWU_snx
        else
            echo "${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx not available" >>  $logf
            exit
        endif
    endif
    if( -e ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx ) then
#       Convert the sinex to globk binary hfile
        htoglb ../CWU_glbf/ ' ' -n=GPSW -f=cwu.d -d=tr -e -m=1024 ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx >>  $logf
    endif
endif
#
# See if the CWU c file is available in the fto area
set cwuc = d   # Hfupd only for the .d. file
if ( ! -e ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.c.gls ) then
#   See if already in sinex area
    if( ! -e ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.c.snx ) then
        if ( -e ${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.c.snx ) then 
            \mv ${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.c.snx ../CWU_snx
            \mv ${srcd}/CWU/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.c.rms ../CWU_snx
        endif
    endif
    if( -e ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.c.snx ) then
#       Convert the sinex to globk binary hfile
        htoglb ../CWU_glbf/ ' ' -n=GPSW -f=cwu.c -d=tr -e -m=1024 ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.c.snx >>  $logf
        set cwuc = cd  # Hfupd on both c and d files
    endif
endif
# 
# Run hfupd to check the status
if( $hfupd == 'Y' ) then
   echo "HFUPD Check " >> $logf
# Make special station.info with only these sites
   tail -1 $logf >> $logf
   set ss = `grep '^....\. ....001A ' $logf | awk '{if( NR == 1 ) {printf("%4s",substr($2,1,4))} else {printf("|%4s",substr($2,1,4))}}'`
   head -4 station.info >! station.info_${gpsw}${gpsd}d
   grep '^*SITE  Station ' station.info >> station.info_${gpsw}${gpsd}d
   tail -n +4 station.info | egrep $ss >> station.info_${gpsw}${gpsd}d
#   hfupd -s station.info -u ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.d.gls ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.d.gls  >>  $logf
   hfupd -s station.info_${gpsw}${gpsd}d  ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.d.gls ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.[${cwuc}].gls  >>  $logf
endif
 
#### See if USGS products are available
csh USG_get.cmd -d $yr $doy -t F >> $logf
#
#########################
# Set the time stamp for these runs

set ts = `date +"%Y%m%d%H%M%S"`
echo "PRODUCT TAG "$ts >> $logf
echo "COMBINED SOLUTION campd d" >> $logf
#
#  Check list of sites
set tx = `date +"%Y%m%d%H%M%S"`
ls ../???_glbf/h${gpsw}${gpsd}_1200_???.d.gls >! h${gpsw}${gpsd}.d.gdl
glist h${gpsw}${gpsd}.d.gdl  h${gpsw}${gpsd}.d.glist >> $logf
grep 'P$' h${gpsw}${gpsd}.d.glist >> $logf

#  Now get the list of sites in the combined set for this day
ls ../[BN]??_glbf/h${gpsw}${gpsd}_1200_[bn]??.[bcd].gls  >! a${tx}.gdl
glist a${tx}.gdl | grep 'P$' | tail -n +4 | awk '{print substr($8,1,4)}' | sort -u >! a${tx}.lst

# Get the date of this comparison
set compdate = `glist a${tx}.gdl | grep '^ ... .. ..     1 ' | awk '{printf("%4.4d %2.2d %2.2d",$1+2000,$2,$3)}'`
set compweek = `doy $compdate | head -2 | tail -1 | awk '{printf("%4.4dw%1.1dd",$3,$7)}'` 

# Get CWU full list   
ls ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.[bcd].gls  >! b${tx}.gdl
glist b${tx}.gdl | grep 'P$' | tail -n +4 | awk '{print substr($8,1,4)}' | sort -u >! b${tx}.lst
#
# Generate the merged RMS file for this day
# Get list of sites
set sites = `grep -h '^ ' ../[NB]??_snx/[bn]??${gpsw}${gpsd}.${yr}${mth}${dom}.[bcd].rms ../CWU_snx/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.[cbd].rms | awk '{print $1}' | sort -u`
set rmsf = ../COM_snx/com${gpsw}${gpsd}.${yr}${mth}${dom}.d.rms
echo "RMS File from " `ls ../[NB]??_snx/[bn]??${gpsw}${gpsd}.${yr}${mth}${dom}.[bcd].rms ../CWU_snx/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.[cbd].rms` >! $rmsf
echo "Format Version : 1.1.0" >> $rmsf
echo "Release Date   : $ts" >> $rmsf
echo "Start Field Description" >> $rmsf
echo "Dot#            4-character identifier for a given station" >> $rmsf
echo "PBO_#           Number 30-sec phase epochs in 24-hours for combined RMS calculation" >> $rmsf
echo "PRMS            Root-mean-square (RMS) scatter of combined phase residuals, mm" >> $rmsf
echo "CWU_#           Number 30-sec phase epochs in 24-hours for CWU RMS calculation" >> $rmsf
echo "CRMS            Root-mean-square (RMS) scatter of CWU phase residuals, mm" >> $rmsf
echo "NMT_#           Number 30-sec phase epochs in 24-hours for NMT or BSL (prior to Feb 2006) RMS calculation" >> $rmsf
echo "NRMS            Root-mean-square (RMS) scatter of NMT or BSL phase residuals, mm" >> $rmsf
echo "A               Coefficient from model fit RMS^2(elev) = A^2 + B^2/sin(elev)^2 where elev is elevation angle, mm" >> $rmsf
echo "B               Coefficient from model fit, mm" >> $rmsf
echo "GPSW            GPS Week for 24-hour processing day" >> $rmsf
echo "D               GPS Day of week for 24-hour processing day" >> $rmsf
echo "YYYYMMDD        Year, month, day of month for 24-hour processing day" >> $rmsf
echo "End Field Description " >> $rmsf
echo "*Dot#  PBO_#   PRMS    CWU_#   CRMS     NMT_#  NRMS        A      B GPSW D YYYYMMDD" >> $rmsf
#
# Extract lines for each site.  
foreach s (`echo $sites`)
    set nmtstat = `grep -h $s ../[NB]??_snx/[nb]??${gpsw}${gpsd}.${yr}${mth}${dom}.[bcd].rms |  awk '{n=n+$2}{r=r+$3}{a=a+$4}{b=b+$5} END {if ( NR > 0 ) {print n/NR,r/NR,a/NR,b/NR} else {print "No"}}'` 
    set cwustat = `grep -h $s ../CWU_snx/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.[bcd].rms |  awk '{n=n+$2}{r=r+$3} END {if ( NR > 0 ) {print n*10/NR,r/NR} else {print "No"}}'`
    if ( $nmtstat[1] == No ) then  
        echo $s $cwustat ${gpsw} ${gpsd} ${yr}${mth}${dom} | awk '{printf(" %s  %5d %6.1f    %5d %6.1f         -     -       -      -  %4.4d %1d %8d\n",$1,$2,$3,$2,$3,$4,$5,$6)}' >> $rmsf 
    else if ( $cwustat[1] == No ) then
        echo $s $nmtstat ${gpsw} ${gpsd} ${yr}${mth}${dom} | awk '{printf(" %s  %5d %6.1f        -     -      %5d %6.1f  %6.1f %6.1f %4.4d %1d %8d\n",$1,$2,$3,$2,$3,$4,$5,$6,$7,$8)}'>> $rmsf
    else
        echo $s $cwustat $nmtstat ${gpsw} ${gpsd} ${yr}${mth}${dom} | awk '{printf(" %s  %5d %6.1f    %5d %6.1f     %5d %6.1f  %6.1f %6.1f %4.4d %1d %8d\n",$1,($2+$4)/2,($3+$5)/2,$2,$3,$4,$5,$6,$7,$8,$9,$10)}'>> $rmsf
    endif 

end 

echo "*SC Statistics of missing stations for $compdate GPS Week $compweek" >>  $logf
echo "*SC      NMT   CWU  COM #    RMS    CWU #    RMS     NMT #    RMS      A      B" >> $logf
echo "*SC                          mm              mm               mm      mm     mm" >> $logf           
set nmtlst = `comm -3 a${tx}.lst b${tx}.lst | awk -F '\t' '{if( NF == 1 ) {print substr($1,1,4)}}'`
set cwulst = `comm -3 a${tx}.lst b${tx}.lst | awk -F '\t' '{if( NF == 2 ) {print substr($2,1,4)}}'`
set cnt = 0 
foreach s (`echo $nmtlst`)
    @ cnt = $cnt + 1
    grep $s $rmsf | awk -v cnt=$cnt '{printf("*SC %4d %s       %s\n",cnt, $1, substr($0,8))}' >> $logf
end
if ( $cnt > 0 ) echo " " >> $logf
set cnt = 0 
foreach s (`echo $cwulst`)
    @ cnt = $cnt + 1
    grep $s $rmsf | awk -v cnt=$cnt '{printf("*SC %4d       %s %s\n",cnt, $1, substr($0,8))}' >> $logf
end
\rm a${tx}.* b${tx}.* h${gpsw}${gpsd}.d.gdl h${gpsw}${gpsd}.d.glist

# Now run the globk solutions on the centers.
cd ../COM
\rm com${gpsw}${gpsd}.d.* >&! /dev/null 
# Weights here are sqrt(2) times each center to keep sigma ~correct
ls ../[NB]??_glbf/h${gpsw}${gpsd}_1200_[nb]??.[bcd].gls | awk '{print $1 "  1.4"}' > ! com${gpsw}${gpsd}.d.gdl
ls ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.[bcd].gls | awk '{print $1 "  9.6"}' >> com${gpsw}${gpsd}.d.gdl
ls ../USG_glbf/h${gpsw}${gpsd}_1200_usg.b.glx | awk '{print $1 "  1.4"}' >> com${gpsw}${gpsd}.d.gdl

globk 6  com${gpsw}${gpsd}.d.prt com${gpsw}${gpsd}.d.log com${gpsw}${gpsd}.d.gdl ../tables/globk_rep.cmd >&! /dev/null

## Save the sinex file from the combinaed run
glbtosnx ../products '' com${gpsw}${gpsd}.d.glb     pbo${gpsw}${gpsd}.campd_loose.snx.${ts}
glbtosnx ../products '' com${gpsw}${gpsd}.d.glb.CON pbo${gpsw}${gpsd}.campd_snf01.snx.${ts}
\cp -p ../COM_snx/com${gpsw}${gpsd}.${yr}${mth}${dom}.d.rms ../products/pbo${gpsw}${gpsd}.campd_snf01.rms.${ts}
\rm  com${gpsw}${gpsd}.d.sol com${gpsw}${gpsd}.d.glb.CON com${gpsw}${gpsd}.d.com
#
# Check for site coordinates that we do not have and those that do no match aprioiri
set apfs = `grep -i apr_file ../tables/globk_rep.cmd ../tables/glorg_rep.cmd | awk '{print $3}'`
#
sh_exglk -f com${gpsw}${gpsd}.d.org -pos t.pos
set sites = `grep '^ ' t.pos | grep -v '_X' | awk '{print substr($13,1,8)}'`
# Now check the quality of each site position.  
grep 'POS S' com${gpsw}${gpsd}.d.org  | awk '{print "*BC "substr($0,17)}' >> ../control/${logf}
set badout = 0
set badlist = ""
set nadd = 0
foreach s ( `echo $sites` )
#
    set s4 = `echo $s | awk '{print substr($1,1,4)}'`
#   See if this site is in apriori files.
#   Chi[1] 2-D (mm), Chi[2] dH mm; chi[3] = 2D sigma Normalized, chi[4] height normalized; chi[5] 3-D normalized
    set chi = `grep $s t.pos | awk '{print sqrt(($3^2+$4^2)/2), sqrt($10^2), sqrt((($3/$7)^2+($4/$8)^2)/2), sqrt(($10/$12)^2), sqrt((($3/$7)^2+($4/$8)^2+($10/$12)^2)/3)}'` 
#
#   See if site is in apriori files
    set inapfs = `grep $s $apfs | wc -l`
    if( $inapfs > 0 ) then
#       Site is in aprori files; see if anomalous: more than 4-sigma from apriori
        set bad = `echo $chi[5] | awk '{if( $1 > 4 ) {print "1"} else {print "0"}}'`
        if ( $bad == 1 ) then
           if ( $badout == 0 ) then
              echo "*BC Sites with large position adjustments from combined solution" >> ../control/${logf}
              echo "*BC Num     Site     dE    +-      dN     +-    dH     +-      COM #    RMS    CWU #    RMS     NMT #    RMS " >> ../control/${logf}
           endif
           @ badout = $badout + 1; set badlist = `echo $badlist $s`
           echo $badout | awk '{printf("*BC %3d",$1)}' >> ../control/${logf}
           grep $s  t.pos | awk '{printf(" %9s %6.1f %6.1f %6.1f %6.1f %6.1f %6.1f ",$13,$3,$7,$4,$8,$10,$12)}' >> ../control/${logf}
           grep $s4 $rmsf | awk '{printf(" %s",substr($0,6,48))}' >> ../control/${logf}  
           set innew = `grep '^ ' ../tables/PBO_new.apr | grep $s | wc -l`
           if( $innew > 0 ) then
              echo "Newer site" >> ../control/${logf}
           else
              echo "" >> ../control/${logf}
           endif
        endif
    else
#       Add site to Updated file
        set OK = `grep Apr. com${gpsw}${gpsd}.d.org | grep $s | awk '{if ( $12 < 0.01 ) {print substr($0,5)}}' | wc -c`
        if( $OK > 0 ) then 
            if ( $nadd == 0 ) then
                 echo "* Site added "`date` >> ../tables/PBO_new.apr 
            endif
            @ nadd++
            grep Apr. com${gpsw}${gpsd}.d.org | grep $s | awk '{if ( $12 < 0.01 ) {print substr($0,5)}}' >> ../tables/PBO_new.apr
        endif
    endif
end
                
if( -e ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.d.gls ) then
    cd ../NMT
    \rm nmt${gpsw}${gpsd}.d.* >&! /dev/null
    ls ../[BN]??_glbf/h${gpsw}${gpsd}_1200_???.[bcd].gls  | awk '{print $1 "  0.7"}' >! nmt${gpsw}${gpsd}.d.gdl

    globk 6  nmt${gpsw}${gpsd}.d.prt nmt${gpsw}${gpsd}.d.log nmt${gpsw}${gpsd}.d.gdl ../tables/globk_rep.cmd >&! /dev/null
# Save the sinex file from the combinaed run
    \cp -p ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx ../products/nmt${gpsw}${gpsd}.campd_loose.snx.${ts}
    glbtosnx ../products '' nmt${gpsw}${gpsd}.d.glb.CON nmt${gpsw}${gpsd}.campd_snf01.snx.${ts}
    \rm  nmt${gpsw}${gpsd}.d.sol nmt${gpsw}${gpsd}.d.glb.CON nmt${gpsw}${gpsd}.d.com
#
    sh_exglk -f nmt${gpsw}${gpsd}.d.org -pos t.pos
    set sites = `grep '^ ' t.pos | grep -v '_X' | awk '{print substr($13,1,8)}'`
# Now check the quality of each site position.  
    grep 'POS S' nmt${gpsw}${gpsd}.d.org  | awk '{print "*BB "substr($0,17)}' >> ../control/${logf}
    grep BAD  nmt${gpsw}${gpsd}.d.log | awk '{printf("*BB Gross Error %s dXYZ %10.3f %10.3f %10.3f m\n",$6,$10,$11,$12)}' >> ../control/${logf}
    set badout = 0
    foreach s ( `echo $sites` )
#
        set s4 = `echo $s | awk '{print substr($1,1,4)}'`
#       See if this site is in apriori files.
#       Chi[1] 2-D (mm), Chi[2] dH mm; chi[3] = 2D sigma Normalized, chi[4] height normalized; chi[5] 3-D normalized
        set chi = `grep $s t.pos | awk '{print sqrt(($3^2+$4^2)/2), sqrt($10^2), sqrt((($3/$7)^2+($4/$8)^2)/2), sqrt(($10/$12)^2), sqrt((($3/$7)^2+($4/$8)^2+($10/$12)^2)/3)}'` 
#
#       See if site is in apriori files
        set bad = `echo $chi[5] | awk '{if( $1 > 4 ) {print "1"} else {print "0"}}'`
        if ( $bad == 1 ) then
           if ( $badout == 0 ) then
              echo "*BB Sites with large position adjustments from combined solution" >> ../control/${logf}
              echo "*BB Num     Site     dE    +-      dN      +-    dH     +-     COM #    RMS    CWU #    RMS     NMT #    RMS" >> ../control/${logf}
           endif
           @ badout = $badout + 1; set badlist = `echo $badlist $s`
           echo $badout | awk '{printf("*BB %3d",$1)}' >> ../control/${logf}
           grep $s  t.pos | awk '{printf(" %9s %6.1f %6.1f %6.1f %6.1f %6.1f %6.1f ",$13,$3,$7,$4,$8,$10,$12)}' >> ../control/${logf}
           grep $s4 $rmsf | awk '{printf(" %s",substr($0,6,48))}' >> ../control/${logf}  
           set innew = `grep '^ ' ../tables/PBO_new.apr | grep $s | wc -l`
           if( $innew > 0 ) then
              echo "Newer site" >> ../control/${logf}
           else
              echo "" >> ../control/${logf}
           endif
        endif
    end

endif
                

cd ../CWU
\rm cwu${gpsw}${gpsd}.d.* >&! /dev/null
ls ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.[bcd].gls | awk '{print $1 "  4.8"}'>! cwu${gpsw}${gpsd}.d.gdl
#ls cwu${gpsw}${gpsd}.b.glb >> cwu${gpsw}${gpsd}.d.gdl

globk 6  cwu${gpsw}${gpsd}.d.prt cwu${gpsw}${gpsd}.d.log cwu${gpsw}${gpsd}.d.gdl ../tables/globk_rep.cmd >&! /dev/null
# Save the sinex file from the combinaed run
\cp -p ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.d.snx ../products/cwu${gpsw}${gpsd}.campd_loose.snx.${ts}
glbtosnx ../products '' cwu${gpsw}${gpsd}.d.glb.CON cwu${gpsw}${gpsd}.campd_snf01.snx.${ts}
\rm cwu${gpsw}${gpsd}.d.sol cwu${gpsw}${gpsd}.d.glb.CON cwu${gpsw}${gpsd}.d.com
#
sh_exglk -f cwu${gpsw}${gpsd}.d.org -pos t.pos
set sites = `grep '^ ' t.pos | grep -v '_X' | awk '{print substr($13,1,8)}'`
# Now check the quality of each site position.  
grep 'POS S' cwu${gpsw}${gpsd}.d.org  | awk '{print "*BW "substr($0,17)}' >> ../control/${logf}
grep BAD  cwu${gpsw}${gpsd}.d.log | awk '{printf("*BW Gross Error %s dXYZ %10.3f %10.3f %10.3f m\n",$6,$10,$11,$12)}' >> ../control/${logf}
set badout = 0
foreach s ( `echo $sites` )
#
    set s4 = `echo $s | awk '{print substr($1,1,4)}'`
#   See if this site is in apriori files.
#   Chi[1] 2-D (mm), Chi[2] dH mm; chi[3] = 2D sigma Normalized, chi[4] height normalized; chi[5] 3-D normalized
    set chi = `grep $s t.pos | awk '{print sqrt(($3^2+$4^2)/2), sqrt($10^2), sqrt((($3/$7)^2+($4/$8)^2)/2), sqrt(($10/$12)^2), sqrt((($3/$7)^2+($4/$8)^2+($10/$12)^2)/3)}'` 
#
#   See if site is in apriori files
    set bad = `echo $chi[5] | awk '{if( $1 > 4 ) {print "1"} else {print "0"}}'`
    if ( $bad == 1 ) then
       if ( $badout == 0 ) then
          echo "*BW Sites with large position adjustments from combined solution" >> ../control/${logf}
          echo "*BW Num     Site     dE    +-       dN      +-    dH     +-    COM #    RMS    CWU #    RMS     NMT #    RMS" >> ../control/${logf}
       endif
       @ badout = $badout + 1; set badlist = `echo $badlist $s`
       echo $badout | awk '{printf("*BW %3d",$1)}' >> ../control/${logf}
       grep $s  t.pos | awk '{printf(" %9s %6.1f %6.1f %6.1f %6.1f %6.1f %6.1f ",$13,$3,$7,$4,$8,$10,$12)}' >> ../control/${logf}
       grep $s4 $rmsf | awk '{printf(" %s",substr($0,6,48))}' >> ../control/${logf}  
       set innew = `grep '^ ' ../tables/PBO_new.apr | grep $s | wc -l`
       if( $innew > 0 ) then
          echo "Newer site" >> ../control/${logf}
       else
          echo "" >> ../control/${logf}
       endif
    endif
end
                
#
# Now see how all the bad sites compare
set badlist = `echo $badlist | awk '{for (i=1; i<=NF; i++) printf " %s\n", $i}' | sort -u`
foreach s (`echo $badlist`)
   grep "^  [ 123]" ../[CNB]??/???${gpsw}${gpsd}.d.org | egrep -v 'coordinate|XYZ' | grep $s | awk '{print "*BA ",$0}' >> ../control/${logf}
   echo "*BA +++" >> ../control/${logf}
end

#### Send off the sinex products
if( $ldm == "Y" ) then 
   pushd ../products
   csh ../control/sh_gzip_ts ${ts}
   ssh -n ldm@everest.mit.edu "cd /net/chandler/raid9/tah/ACC_PBO/products; ~/bin/sh_pqinsert *.${ts}"
   popd
endif

#### See if we will send summary
if( $mailto != "N" ) then
   pushd ../control
   csh sh_summary -f $logf -m $mailto
   popd
endif




 


