#!/bin/csh -f
#
# PBO Shell script for processing rapid results from CWU and NMT ACs
#
# See if arguments passed
if( $#argv == 0 ) then
   grep '^## ' $0 | awk '{print substr($0,3)}'
# Here are the options
## Usage: PBO_rapid.cmd <options> 
## where the following options are avaiable
##  -d yr day    where yr and day are to processed e.g. 1997 153
##  -r day       where day is number of days before current date
##  -m mailto    will invoke summary generation and sending of summary email 
##  -ldm         Put results into LDM queue
##  -ts          Update the time series files
##  -globk_only  Run globk only (needed if gamit runs are re-done mamually
##  -no_hfupd    Don't run hfupd to check site meta data
##  -no_plots    Don't plot the times for the anomaous sites
##  -clear       Clears Binary hfiles and previous log and start again
##
## Script run from <proc_dir>/control directory
##
   exit

endif
setenv INSTITUTE MIT
# Now set up defaults
set glbk_only = 'N'
set hfupd     = 'Y'
set clear     = 'N'
set mailto    = 'N'
set ldm       = 'N'
set makets    = 'N'
set plots     = 'Y'
#
set srcd = '/data30/ftp/pub/incoming/ACC_PBO/'
set ts = `date +"%H%M%S"`
#
#
# Now read the arguments
foreach a ($argv)
switch($a)
    case -d:
        set yr = $argv[2]
        set doy = $argv[3]

#       Get the gpsweek
        set jd   = `doy $yr $doy | tail -3 | head -1 | awk '{print $8}'`
        set gpsw = `doy $jd | tail -2 | head -1 | awk '{print $3}'`
        set gpsd = `doy $jd | tail -2 | head -1 | awk '{print substr($7,1,1)}'`
        set yr   = `doy $jd | tail -3 | head -1 | awk '{print substr($2,1,4)}'`
        set yr2  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,3,2)}'`
        set mth  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,6,2)}'`
        set dom  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,9,2)}'`
        set doy  = `doy $jd | tail -3 | head -1 | awk '{print $6}'`
        set mjd  = `doy $yr $doy | tail -3 | head -1 |awk '{print int($10)}'`
        set jdn  = `doy | tail -3 | head -1 | awk '{print int($10)}'`
        @ dd = $jdn - $mjd
        breaksw
    case -r:
        set dd = $argv[2]

#       Now get the day number to process
        set jd = `doy | tail -3 | head -1 | awk '{print int($10)}'`
        @ jd = $jd - $dd
        set gpsw = `doy $jd | tail -2 | head -1 | awk '{print $3}'`
        set gpsd = `doy $jd | tail -2 | head -1 | awk '{print substr($7,1,1)}'`
        set yr   = `doy $jd | tail -3 | head -1 | awk '{print substr($2,1,4)}'`
        set yr2  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,3,2)}'`
        set mth  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,6,2)}'`
        set dom  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,9,2)}'`
        set doy  = `doy $jd | tail -3 | head -1 | awk '{print $6}'`
       
        breaksw
    case -gl*:
        set glbk_only = "Y"
        breaksw
    case -no_h*:
        set hfupd = "N"
        breaksw
    case -no_p*:
        set plots = "N"
        breaksw
    case -cl*:
        set clear = "Y"
        breaksw
    case -m*:
        set mailto = $argv[2]
        breaksw
    case -ldm:
        set ldm = "Y"
        breaksw
    case -ts:
        set makets = "Y"
        breaksw
    default:
#       echo Unknown option $a
#       grep '^## ' $0 | awk '{print substr($0,3)}'
#       exit

endsw
shift
end

# Set email test on disk usage:
set esent = N
# Check we have enough disk
set diskOK = N
while ( $diskOK == N )
   set dfree = `df -k . ../PBO_products | grep raid | awk '{printf("%6.1f\n", $4/(1024*1024))}'`
   set diskOK = `echo $dfree | awk '{if( $1 < 5.0 || $2 < 5.0 ) {print "N"} else {print "Y"}}'`
   if( $diskOK == N ) then
      if( $esent == N  ) then
         set subj = `echo $gpsw $gpsd $dfree | awk '{printf("PBO RAPID low disk Processing %4.4dW %1dD, Free %6.1f %6.1f Gb",$1,$2,$3,$4)}'`
         mail -s "$subj" tah@mit.edu <<!
Not enough disk space Free $dfree GB
!

         set esent = Y
      endif
      sleep 10m
   endif
end


# Check to see if any update files are in the ftp area
pushd ~/fa/
set upd = `ls ???/*.update`
set nupd = `echo $upd | wc -w`
if( $nupd > 0 ) then
   echo "Renaming $nupd files with .update extent"
   foreach f (`echo $upd` )
      set nf = $f:r
     echo $f $nf
     \mv -f $f $nf
   end
endif
popd


# Adjust the $gpsw
set gpsw = `echo $gpsw | awk '{printf("%04d",$1)}'`
set doy = `echo $doy | awk '{printf("%03d",$1)}'`
# Set up the log file
set logf = PBO_RAP_${gpsw}${gpsd}.log
if( $clear == "Y" ) then
   \rm $logf >&! /dev/null
   \rm ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.a.gls >&! /dev/null
   \rm ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.a.gls >&! /dev/null
endif
if( ! -e $logf  ) then
   touch $logf
endif
echo "Creating/Updating $logf"
echo "--------------------------------------------------" >> $logf
echo -n "++ LOG UPDATE ++ " >> $logf
date >> $logf
echo "--------------------------------------------------" >> $logf
echo "OPTIONS: MAIL $mailto LDM $ldm TimeSeries $makets Plots $plots" >> $logf

# Check to see if any update files are in the ftp area
pushd ~/fa/
set upd = `ls ???/*.update`
set nupd = `echo $upd | wc -w`
if( $nupd > 0 ) then
   echo "Renaming $nupd files" >> ~/ACC_PBO/anal/control/${logf}
   foreach f (`echo $upd` )
      set nf = $f:r
      echo "\mv $f $nf" >> ~/ACC_PBO/anal/control/${logf}
      \mv -f $f $nf >> ~/ACC_PBO/anal/control/${logf}
   end
endif
popd

#
# See if NMT file is already in glbf area
if( -e ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx.gz || \
    -e ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx ) then
   echo "Removing older NMT files"
   \rm ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.a.gls
   \rm ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx
endif

if ( ! -e ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.a.gls ) then
#   See if already in sinex area
    if( ! -e ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx ) then
        if ( -e ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx ) then 
            \mv ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx ../NMT_snx/
            \mv ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.rms ../NMT_snx/
            \mv ${srcd}/NMT/H${yr2}${mth}${dom}_nmtar.GLX ../NMT_glbf/
        else if ( -e ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx.gz ) then 
            \mv ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx.gz ../NMT_snx/
             gzip -d ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx.gz
            \mv ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.rms ../NMT_snx/
            \mv ${srcd}/NMT/H${yr2}${mth}${dom}_nmtar.GLX ../NMT_glbf/
        else
            echo "${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx not available" >> $logf
        endif
    endif 
    if( -e ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx ) then
#       Convert the sinex to globk binary hfile
        htoglb ../NMT_glbf/ ' ' -n=GPSW -f=nmt.a -e -d=tr -m=1024 ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx >>  $logf
    endif
endif
#
# See if the CWU file is available
if( -e ${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx ) then
   echo "Removing older CWU files"
   \rm ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.a.gls
   \rm ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx
endif


if ( ! -e ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.a.gls ) then
#   See if already in sinex area
    if( ! -e ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx ) then
        if ( -e ${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx ) then 
            \mv ${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx ../CWU_snx/
            \mv ${srcd}/CWU/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.a.rms ../CWU_snx/
        else
            echo "${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx not available" >>  $logf
        endif
    endif
    if( -e ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx ) then
        htoglb ../CWU_glbf/ ' ' -n=GPSW -f=cwu.a -d=tr -e -m=1024 ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx >>  $logf
    endif
endif
#

# See if the MIT files exist
if ( ! -e ../MIT_glbf/h${gpsw}${gpsd}_1200_mit.a.glx ) then
    if( -e ../../gsoln/pbo_${yr2}${doy}_ra.GLX ) then
       \cp -p ../../gsoln/pbo_${yr2}${doy}_ra.GLX ../MIT_glbf/h${gpsw}${gpsd}_1200_mit.a.glx
       \cp -p ../../control/RMS.${yr}_${doy}ra ../MIT_snx/mit${gpsw}${gpsd}.${yr}${mth}${dom}.a.rms
    else
        echo "MIT_glbf/h${gpsw}${gpsd}_1200_mit.a.glx not available" >>  $logf
    endif
endif
#
# Run hfupd to check the status
if( $hfupd == 'Y' ) then
   echo "HFUPD Check `date` " >> $logf
# Make special station.info with only these sites
#  tail -1 $logf >> $logf
#  set ss1 = `grep '^....\. ....001A ' $logf | sort -u -k 2.1,2.5 | head -500                 | awk '{if( NR == 1 ) {printf("^ %4s ",substr($2,1,4))} else {printf("|^ %4s ",substr($2,1,4))}}'`
#  set ss2 = `grep '^....\. ....001A ' $logf | sort -u -k 2.1,2.5 | tail -n +501  | head -500 | awk '{if( NR == 1 ) {printf("^ %4s ",substr($2,1,4))} else {printf("|^ %4s ",substr($2,1,4))}}'`
#  set ss3 = `grep '^....\. ....001A ' $logf | sort -u -k 2.1,2.5 | tail -n +1001 | head -500 | awk '{if( NR == 1 ) {printf("^ %4s ",substr($2,1,4))} else {printf("|^ %4s ",substr($2,1,4))}}'`
#  head -4 station.info >! station.info_${gpsw}${gpsd}a
#  grep '^*SITE  Station ' station.info >> station.info_${gpsw}${gpsd}a
#  tail -n +4 station.info | egrep -i "$ss1" >> station.info_${gpsw}${gpsd}a
#  set nss = `echo $ss2 | wc -c`
#  if( $nss > 4 ) then
#      tail -n +4 station.info | egrep -i "$ss2" >> station.info_${gpsw}${gpsd}a
#      set nss = `echo $ss3 | wc -c`
#      if( $nss > 4 ) then
#          tail -n +4 station.info | egrep -i "$ss3" >> station.info_${gpsw}${gpsd}a
#      endif
#  endif

   hfupd -s station.info -cwu  ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.a.gls ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.a.gls  >>  $logf
   echo "HFUPD done `date` " >> $logf
endif

#### See if USGS products are available
# csh USG_get.cmd -d $yr $doy -t R  >>  $logf
#
#########################
# Set the time stamp for thiese runs

set ts = `date +"%Y%m%d%H%M%S"`
echo "PRODUCT TAG "$ts >>  $logf
echo "COMBINED SOLUTION rapid a" >> $logf

#########################
# Move any old rapid products to old products directory
set num_old = `ls ../products/???${gpsw}${gpsd}.r* |& grep -v 'No match' | wc -l`
if( $num_old != 0 ) then
   echo "Removing old products:" >> $logf
   ls ../products/???${gpsw}${gpsd}.r* >> $logf
#   \mv ../products/???${gpsw}${gpsd}.r* ../old_products/
   \rm ../products/???${gpsw}${gpsd}.r* 
endif


#
#  Check list of sites
set tx = `date +"%Y%m%d%H%M%S"`
ls ../[CN]??_glbf/h${gpsw}${gpsd}_1200_???.a.gls >! h${gpsw}${gpsd}.a.gdl
glist h${gpsw}${gpsd}.a.gdl  h${gpsw}${gpsd}.a.glist >> $logf
#   grep 'P$' h${gpsw}${gpsd}.glist | grep ' 1 20' >>  $logf

#  Now get the list of sites not in either
ls ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.a.gls >! a${tx}.gdl
glist a${tx}.gdl | grep 'P$' | awk '{print $8}' | sort >! a${tx}.lst
#
# Get the date of this comparison
set compdate = `glist a${tx}.gdl | grep '^ ... .. ..     1 ' | awk '{printf("%4.4d %2.2d %2.2d",$1+2000,$2,$3)}'`
set compweek = `doy $compdate | head -2 | tail -1 | awk '{printf("%4.4dw%1.1dd",$3,$7)}'`    
ls ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.a.gls >! b${tx}.gdl
glist b${tx}.gdl | grep 'P$' | awk '{print $8}' | sort >! b${tx}.lst

# Generate the merged RMS file for this day
# Get list of sites
set sites = `grep -h '^ ' ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.rms ../CWU_snx/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.a.rms | awk '{print $1}' | sort -u`
set rmsf = ../COM_snx/com${gpsw}${gpsd}.${yr}${mth}${dom}.a.rms
echo "RMS File from " `ls ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.rms ../CWU_snx/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.a.rms` >! $rmsf
echo "Format Version : 1.1.0" >> $rmsf
echo "Release Date   : $ts" >> $rmsf
echo "Start Field Description" >> $rmsf
echo "Dot#            4-character identifier for a given station" >> $rmsf
echo "PBO_#           Number 30-sec phase epochs in 24-hours for combined RMS calculation" >> $rmsf
echo "PRMS            Root-mean-square (RMS) scatter of combined phase residuals, mm" >> $rmsf
echo "CWU_#           Number 30-sec phase epochs in 24-hours for CWU RMS calculation" >> $rmsf
echo "CRMS            Root-mean-square (RMS) scatter of CWU phase residuals, mm" >> $rmsf
echo "NMT_#           Number 30-sec phase epochs in 24-hours for NMT or BSL (prior to Feb 2006) RMS calculation" >> $rmsf
echo "NRMS            Root-mean-square (RMS) scatter of NMT or BSL phase residuals, mm" >> $rmsf
echo "A               Coefficient from model fit RMS^2(elev) = A^2 + B^2/sin(elev)^2 where elev is elevation angle, mm" >> $rmsf
echo "B               Coefficient from model fit, mm" >> $rmsf
echo "GPSW            GPS Week for 24-hour processing day" >> $rmsf
echo "D               GPS Day of week for 24-hour processing day" >> $rmsf
echo "YYYYMMDD        Year, month, day of month for 24-hour processing day" >> $rmsf
echo "End Field Description " >> $rmsf
echo "*Dot#  PBO_#   PRMS    CWU_#   CRMS     NMT_#  NRMS        A      B GPSW D YYYYMMDD" >> $rmsf
#
# Extract lines for each site.  
foreach s (`echo $sites`)
    set nmtstat = `grep $s ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.rms |  awk '{n=n+$2}{r=r+$3}{a=a+$4}{b=b+$5} END {if ( NR > 0 ) {print n/NR,r/NR,a/NR,b/NR} else {print "No"}}'` 
    set cwustat = `grep $s ../CWU_snx/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.a.rms |  awk '{n=n+$2}{r=r+$3} END {if ( NR > 0 ) {print n*10/NR,r/NR} else {print "No"}}'`
    if ( $nmtstat[1] == No ) then  
        echo $s $cwustat ${gpsw} ${gpsd} ${yr}${mth}${dom} | awk '{printf(" %s  %5d %6.1f    %5d %6.1f         -     -       -      -  %4.4d %1d %8d\n",$1,$2,$3,$2,$3,$4,$5,$6)}' >> $rmsf 
    else if ( $cwustat[1] == No ) then
        echo $s $nmtstat ${gpsw} ${gpsd} ${yr}${mth}${dom} | awk '{printf(" %s  %5d %6.1f        -     -      %5d %6.1f  %6.1f %6.1f %4.4d %1d %8d\n",$1,$2,$3,$2,$3,$4,$5,$6,$7,$8)}'>> $rmsf
    else
        echo $s $cwustat $nmtstat ${gpsw} ${gpsd} ${yr}${mth}${dom} | awk '{printf(" %s  %5d %6.1f    %5d %6.1f     %5d %6.1f  %6.1f %6.1f %4.4d %1d %8d\n",$1,($2+$4)/2,($3+$5)/2,$2,$3,$4,$5,$6,$7,$8,$9,$10)}'>> $rmsf
    endif 

end 

# Check which sites are missing
echo "*SC Statistics of missing stations for $compdate GPS Week $compweek" >>  $logf
echo "*SC      NMT   CWU  COM #    RMS    CWU #    RMS     NMT #    RMS      A      B" >> $logf
echo "*SC                          mm              mm               mm      mm     mm" >> $logf         
set nmtlst = `comm -3 a${tx}.lst b${tx}.lst | awk -F '\t' '{if( NF == 1 ) {print substr($1,1,4)}}'`
set cwulst = `comm -3 a${tx}.lst b${tx}.lst | awk -F '\t' '{if( NF == 2 ) {print substr($2,1,4)}}'`
set cnt = 0 
foreach s (`echo $nmtlst`)
    @ cnt = $cnt + 1
    grep $s $rmsf | awk -v cnt=$cnt '{printf("*SC %4d %s       %s\n",cnt, $1, substr($0,8))}' >> $logf
end
if ( $cnt > 0 ) echo " " >> $logf
set cnt = 0 
foreach s (`echo $cwulst`)
    @ cnt = $cnt + 1
    grep $s $rmsf | awk -v cnt=$cnt '{printf("*SC %4d       %s %s\n",cnt, $1, substr($0,8))}' >> $logf
end

\rm a${tx}.* b${tx}.* h${gpsw}${gpsd}.a.gdl h${gpsw}${gpsd}.a.glist

# Now run the globk solutions on the centers.
cd ../COM
\rm com${gpsw}${gpsd}.a.*
# Weights here are sqrt(2) times each center to keep sigma ~correct
ls ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.a.gls | awk '{print $1 "  1.4"}' >! com${gpsw}${gpsd}.a.gdl
ls ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.a.gls | awk '{print $1 "  9.6"}' >> com${gpsw}${gpsd}.a.gdl
#ls ../USG_glbf/h${gpsw}${gpsd}_1200_usg.a.glx | awk '{print $1 "  1.4"}' >> com${gpsw}${gpsd}.a.gdl

globk 6  com${gpsw}${gpsd}.a.prt com${gpsw}${gpsd}.a.log com${gpsw}${gpsd}.a.gdl ../tables/globk_rep.cmd >&! /dev/null
# Save the sinex file from the combinaed run
glbtosnx ../products +../tables/head.pbo com${gpsw}${gpsd}.a.glb     pbo${gpsw}${gpsd}.rapid_loose.snx.${ts}
glbtosnx ../products +../tables/head.pbo com${gpsw}${gpsd}.a.glb.CON pbo${gpsw}${gpsd}.rapid_nam08.snx.${ts}
\cp -p ../COM_snx/com${gpsw}${gpsd}.${yr}${mth}${dom}.a.rms ../products/pbo${gpsw}${gpsd}.rapid_nam08.rms.${ts}
\rm com${gpsw}${gpsd}.a.sol com${gpsw}${gpsd}.a.glb.CON com${gpsw}${gpsd}.a.com
# If USGS has been used, then
#set nusgs = `grep usg com${gpsw}${gpsd}.a.gdl | wc -l`
#if(  $nusgs > 0 ) then
#    \cp -p ../USG_snx/usg${gpsw}${gpsd}.rapid_loose.snx ../products/usg${gpsw}${gpsd}.rapid_loose.snx.${ts}
#endif
#
# Check for site coordinates that we do not have and those that do no match aprioiri
set apfs = `grep -i "APRIORI file   :"  ../COM/com${gpsw}${gpsd}.a.org | awk '{print $4}'`
#
sh_exglk -f com${gpsw}${gpsd}.a.org -pos t.pos.${ts}
set sites = `grep '^ ' t.pos.${ts} | grep -v '_X' | awk '{print substr($13,1,8)}'`
# Now check the quality of each site position.  
grep 'POS S' com${gpsw}${gpsd}.a.org  | awk '{print "*BC "substr($0,17)}' >> ../control/${logf}
set badout = 0
set badlist = ""
set nadd = 0
foreach s ( `echo $sites` )
#
    set s4 = `echo $s | awk '{print substr($1,1,4)}'`
#   See if this site is in apriori files.
#   Chi[1] 2-D (mm), Chi[2] dH mm; chi[3] = 2D sigma Normalized, chi[4] height normalized; chi[5] 3-D normalized
    set chi = `grep $s t.pos.${ts} | awk '{print sqrt(($3^2+$4^2)/2), sqrt($10^2), sqrt((($3/$7)^2+($4/$8)^2)/2), sqrt(($10/$12)^2), sqrt((($3/$7)^2+($4/$8)^2+($10/$12)^2)/3)}'` 
#
#   See if site is in apriori files
    set inapfs = `grep $s $apfs | wc -l`
    if( $inapfs > 0 ) then
#       Site is in aprori files; see if anomalous: more than 4-sigma from apriori
        set bad = `echo $chi[5] | awk '{if( $1 > 4 ) {print "1"} else {print "0"}}'`
        if ( $bad == 1 ) then
           if ( $badout == 0 ) then
              echo "*BC Sites with large position adjustments from combined solution" >> ../control/${logf}
              echo "*BC Num     Site     dE    +-      dN     +-    dH     +-      COM #    RMS    CWU #    RMS     NMT #    RMS " >> ../control/${logf}
           endif
           @ badout = $badout + 1; set badlist = `echo $badlist $s`
           echo $badout | awk '{printf("*BC %3d",$1)}' >> ../control/${logf}
           grep $s  t.pos.${ts} | awk '{printf(" %9s %6.1f %6.1f %6.1f %6.1f %6.1f %6.1f ",$13,$3,$7,$4,$8,$10,$12)}' >> ../control/${logf}
           grep $s4 $rmsf | awk '{printf(" %s",substr($0,6,48))}' >> ../control/${logf}  
           set innew = `grep '^ ' ../tables/PBO_new.apr | grep $s | wc -l`
           if( $innew > 0 ) then
              echo "Newer site" >> ../control/${logf}
           else
              echo "" >> ../control/${logf}
           endif
        endif
    else
#       Add site to Updated file
        set OK = `grep Apr. com${gpsw}${gpsd}.a.org | grep $s | awk '{if ( $12 < 0.01 ) {print substr($0,5)}}' | wc -c`
        if( $OK > 0 ) then 
            if ( $nadd == 0 ) then
                 echo "* Site added "`date` >> ../tables/PBO_new.apr 
            endif
            @ nadd++
            grep Apr. com${gpsw}${gpsd}.a.org | grep $s | awk '{if ( $12 < 0.01 ) {print substr($0,5)}}' >> ../tables/PBO_new.apr
        endif
    endif
end
\rm t.pos.${ts}
                

cd ../NMT
\rm nmt${gpsw}${gpsd}.a.*
ls ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.a.gls | awk '{print $1 "  0.7"}' >! nmt${gpsw}${gpsd}.a.gdl
globk 6  nmt${gpsw}${gpsd}.a.prt nmt${gpsw}${gpsd}.a.log nmt${gpsw}${gpsd}.a.gdl ../tables/globk_rep.cmd >&! /dev/null
# Save the sinex file from the combinaed run
\cp -p ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx ../products/nmt${gpsw}${gpsd}.rapid_loose.snx.${ts}
glbtosnx ../products +../tables/head.pbo nmt${gpsw}${gpsd}.a.glb.CON nmt${gpsw}${gpsd}.rapid_nam08.snx.${ts}
\rm nmt${gpsw}${gpsd}.a.sol nmt${gpsw}${gpsd}.a.glb.CON nmt${gpsw}${gpsd}.a.com
#
sh_exglk -f nmt${gpsw}${gpsd}.a.org -pos t.pos.${ts}
set sites = `grep '^ ' t.pos.${ts} | grep -v '_X' | awk '{print substr($13,1,8)}'`
# Now check the quality of each site position.  
grep 'POS S' nmt${gpsw}${gpsd}.a.org  | awk '{print "*BB "substr($0,17)}' >> ../control/${logf}
grep BAD  nmt${gpsw}${gpsd}.a.log | awk '{printf("*BB Gross Error %s dXYZ %10.3f %10.3f %10.3f m\n",$6,$10,$11,$12)}' >> ../control/${logf}
set badout = 0
foreach s ( `echo $sites` )
#
    set s4 = `echo $s | awk '{print substr($1,1,4)}'`
#   See if this site is in apriori files.
#   Chi[1] 2-D (mm), Chi[2] dH mm; chi[3] = 2D sigma Normalized, chi[4] height normalized; chi[5] 3-D normalized
    set chi = `grep $s t.pos.${ts} | awk '{print sqrt(($3^2+$4^2)/2), sqrt($10^2), sqrt((($3/$7)^2+($4/$8)^2)/2), sqrt(($10/$12)^2), sqrt((($3/$7)^2+($4/$8)^2+($10/$12)^2)/3)}'` 
#
#   See if site is in apriori files
    set bad = `echo $chi[5] | awk '{if( $1 > 4 ) {print "1"} else {print "0"}}'`
    if ( $bad == 1 ) then
       if ( $badout == 0 ) then
          echo "*BB Sites with large position adjustments from combined solution" >> ../control/${logf}
          echo "*BB Num     Site     dE    +-      dN      +-    dH     +-     COM #    RMS    CWU #    RMS     NMT #    RMS" >> ../control/${logf}
       endif
       @ badout = $badout + 1; set badlist = `echo $badlist $s`
       echo $badout | awk '{printf("*BB %3d",$1)}' >> ../control/${logf}
       grep $s  t.pos.${ts} | awk '{printf(" %9s %6.1f %6.1f %6.1f %6.1f %6.1f %6.1f ",$13,$3,$7,$4,$8,$10,$12)}' >> ../control/${logf}
       grep $s4 $rmsf | awk '{printf(" %s",substr($0,6,48))}' >> ../control/${logf}  
       set innew = `grep $s ../tables/PBO_new.apr | wc -l`
       if ( $innew > 0 ) then
          echo "Newer site" >> ../control/${logf}
       else
          echo "" >> ../control/${logf}
       endif
    endif
end
\rm t.pos.${ts}
                

cd ../CWU
\rm cwu${gpsw}${gpsd}.a.*
ls ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.a.gls | awk '{print $1 "  4.8"}'>! cwu${gpsw}${gpsd}.a.gdl
globk 6  cwu${gpsw}${gpsd}.a.prt cwu${gpsw}${gpsd}.a.log cwu${gpsw}${gpsd}.a.gdl ../tables/globk_rep.cmd >&! /dev/null
# Save the sinex file from the combinaed run
\cp -p ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.a.snx ../products/cwu${gpsw}${gpsd}.rapid_loose.snx.${ts}
glbtosnx ../products +../tables/head.pbo cwu${gpsw}${gpsd}.a.glb.CON cwu${gpsw}${gpsd}.rapid_nam08.snx.${ts}
\rm cwu${gpsw}${gpsd}.a.sol cwu${gpsw}${gpsd}.a.glb.CON cwu${gpsw}${gpsd}.a.com
#
sh_exglk -f cwu${gpsw}${gpsd}.a.org -pos t.pos.${ts}
set sites = `grep '^ ' t.pos.${ts} | grep -v '_X' | awk '{print substr($13,1,8)}'`
# Now check the quality of each site position.  
grep 'POS S' cwu${gpsw}${gpsd}.a.org  | awk '{print "*BW "substr($0,17)}' >> ../control/${logf}
grep BAD  cwu${gpsw}${gpsd}.a.log | awk '{printf("*BW Gross Error %s dXYZ %10.3f %10.3f %10.3f m\n",$6,$10,$11,$12)}' >> ../control/${logf}
set badout = 0
foreach s ( `echo $sites` )
#
    set s4 = `echo $s | awk '{print substr($1,1,4)}'`
#   See if this site is in apriori files.
#   Chi[1] 2-D (mm), Chi[2] dH mm; chi[3] = 2D sigma Normalized, chi[4] height normalized; chi[5] 3-D normalized
    set chi = `grep $s t.pos.${ts} | awk '{print sqrt(($3^2+$4^2)/2), sqrt($10^2), sqrt((($3/$7)^2+($4/$8)^2)/2), sqrt(($10/$12)^2), sqrt((($3/$7)^2+($4/$8)^2+($10/$12)^2)/3)}'` 
#
#   See if site is in apriori files
    set bad = `echo $chi[5] | awk '{if( $1 > 4 ) {print "1"} else {print "0"}}'`
    if ( $bad == 1 ) then
       if ( $badout == 0 ) then
          echo "*BW Sites with large position adjustments from combined solution" >> ../control/${logf}
          echo "*BW Num     Site     dE    +-       dN      +-    dH     +-    COM #    RMS    CWU #    RMS     NMT #    RMS" >> ../control/${logf}
       endif
       @ badout = $badout + 1; set badlist = `echo $badlist $s`
       echo $badout | awk '{printf("*BW %3d",$1)}' >> ../control/${logf}
       grep $s  t.pos.${ts} | awk '{printf(" %9s %6.1f %6.1f %6.1f %6.1f %6.1f %6.1f ",$13,$3,$7,$4,$8,$10,$12)}' >> ../control/${logf}
       grep $s4 $rmsf | awk '{printf(" %s",substr($0,6,48))}' >> ../control/${logf}  
       set innew = `grep $s ../tables/PBO_new.apr | wc -l`
       if( $innew > 0 ) then
          echo "Newer site" >> ../control/${logf}
       else
          echo "" >> ../control/${logf}
       endif
    endif
end
\rm t.pos.${ts}
                


###cd ../MIT
###\rm mit${gpsw}${gpsd}.a.*
###ls ../MIT_glbf/h${gpsw}${gpsd}_1200_mit.a.glx >! mit${gpsw}${gpsd}.a.gdl
###globk 6  mit${gpsw}${gpsd}.a.prt mit${gpsw}${gpsd}.a.log mit${gpsw}${gpsd}.a.gdl ../tables/globk_rep.cmd >&! /dev/null
###\rm mit{gpsw}${gpsd}.a.sol mit${gpsw}${gpsd}.a.glb.CON mit${gpsw}${gpsd}.a.com

###sh_exglk -f mit${gpsw}${gpsd}.a.org -pos t.pos.${ts}
###set sites = `grep '^ ' t.pos.${ts} | grep -v '_X' | awk '{print substr($13,1,8)}'`
#### Now check the quality of each site position.  
###grep 'POS S' mit${gpsw}${gpsd}.a.org  | awk '{print "*BM "substr($0,17)}' >> ../control/${logf}
###grep BAD  mit${gpsw}${gpsd}.a.log | awk '{printf("*BM Gross Error %s dXYZ %10.3f %10.3f %10.3f m\n",$6,$10,$11,$12)}' >> ../control/${logf}
###set badout = 0
###foreach s ( `echo $sites` )
####
###    set s4 = `echo $s | awk '{print substr($1,1,4)}'`
####   See if this site is in apriori files.
####   Chi[1] 2-D (mm), Chi[2] dH mm; chi[3] = 2D sigma Normalized, chi[4] height normalized; chi[5] 3-D normalized
###    set chi = `grep $s t.pos.${ts} | awk '{print sqrt(($3^2+$4^2)/2), sqrt($10^2), sqrt((($3/$7)^2+($4/$8)^2)/2), sqrt(($10/$12)^2), sqrt((($3/$7)^2+($4/$8)^2+($10/$12)^2)/3)}'` 
####
####   See if site is in apriori files
###    set bad = `echo $chi[5] | awk '{if( $1 > 4 ) {print "1"} else {print "0"}}'`
###    if ( $bad == 1 ) then
###       if ( $badout == 0 ) then
###          echo "*BM Sites with large position adjustments from combined solution" >> ../control/${logf}
###          echo "*BM Num     Site     dE    +-       dN      +-    dH     +-" >> ../control/${logf}
###       endif
###       @ badout = $badout + 1; set badlist = `echo $badlist $s`
###       echo $badout | awk '{printf("*BM %3d",$1)}' >> ../control/${logf}
###       grep $s t.pos.${ts} | awk '{printf(" %9s %6.1f %6.1f %6.1f %6.1f %6.1f %6.1f ",$13,$3,$7,$4,$8,$10,$12)}' >> ../control/${logf}
###       set innew = `grep $s ../tables/PBO_new.apr | wc -l`
###       if( $innew > 0 ) then
###          echo "Newer site" >> ../control/${logf}
###       else
###          echo "" >> ../control/${logf}
###       endif
###    endif
###end
#
# Now see how all the bad sites compare
# MOD TAH 070506: Removed additional stations for Acutan volcano.
#set badlist = `echo $badlist  AC11_GPS  ATW2_GPS  AC15_GPS  KOD1_GPS  AC38_GPS  AV05_GPS  AV02_GPS  AV03_GPS  AV01_GPS  AC59_GPS  AC27_GPS`
set badlist = `echo $badlist | awk '{for (i=1; i<=NF; i++) printf " %s\n", $i}' | sort -u`
foreach s (`echo $badlist`)
   grep "^  [ 123]" ../???/[cnb]??${gpsw}${gpsd}.a.org | egrep -v 'coordinate|XYZ' | grep $s | awk '{print "*BA ",$0}' >> ../control/${logf}
   echo "*BA +++" >> ../control/${logf}
end

#  See if time series are to updated and made
if( $makets == "Y" ) then
   pushd ../control
   csh sh_rapid_ts $ts
   if( $ldm == "Y" ) then
       csh sh_pos_tar rapid $ts
   endif
   popd
endif

# Now see if we will make plots of bad sites
#
if( $plots == 'Y' ) then
   pushd  ../control
   while ( -e html.lock ) 
     sleep 1m
   end 
   touch html.lock

   set html = "PBO_Outliers.html"
   echo "<HTML>" >! $html
   echo "<HEAD>" >> $html
   echo "<TITLE>PBO Outlier Sites $ts</TITLE>" >> $html
   echo "</HEAD>" >> $html
   echo '<BODY  link="#0000ff" vlink="#ff0000" BACKGROUND="pboback.jpg">' >> $html
   echo '<font face ="Arial,Helvetica">' >> $html

   echo "<hr><p><H2>PBO Outlier sites for PROD ID $ts</H2> <hr>" >> $html
   echo "<br>" >> $html 
   echo '<table border>' >> $html

   foreach s (`echo $badlist` )
     set site = `echo $s | awk '{print substr($1,1,4)}'`
     ./sh_plot_pbots ../COM/ts_com/${site}.pbo.final_nam08.pos
     ./sh_plot_pbots ../NMT/ts_nmt/${site}.nmt.final_nam08.pos
     ./sh_plot_pbots ../CWU/ts_cwu/${site}.cwu.final_nam08.pos
     echo '<tr>' >> $html
     echo "<th><center>$site</th>" >> $html
     echo '<th><center><A HREF="'$site.PBO.jpg'">PBO</center></th>' >> $html
     if( -e ../COM/ts_com/${site}.pbo.final_nam08.ps ) then
         convert -quality 100 +antialias ps:../COM/ts_com/${site}.pbo.final_nam08.ps $site.PBO.jpg
        \mv $site.PBO.jpg ~/ph/ACC_PBO/
     endif
     if ( -e ../NMT/ts_nmt/${site}.nmt.final_nam08.ps ) then
         echo '<th><center><A HREF="'$site.NMT.jpg'">NMT</center></th>' >> $html
         convert -quality 100 +antialias ps:../NMT/ts_nmt/${site}.nmt.final_nam08.ps $site.NMT.jpg
        \mv $site.NMT.jpg ~/ph/ACC_PBO/
     else
         echo '<th><center>&nbsp </center></th>' >> $html
     endif
     if ( -e ../CWU/ts_cwu/${site}.cwu.final_nam08.ps ) then
         echo '<th><center><A HREF="'$site.CWU.jpg'">CWU</center></th>' >> $html
         convert -quality 100 +antialias ps:../CWU/ts_cwu/${site}.cwu.final_nam08.ps $site.CWU.jpg
        \mv $site.CWU.jpg ~/ph/ACC_PBO/
     else
         echo '<th><center>&nbsp </center></th>' >> $html
     endif

      echo '</tr>' >> $html
   end
   echo "</table>" >> $html

   echo "<br>Last updated `date`" >> $html
   echo "</font>" >> $html
   \cp $html ~/ph/ACC_PBO

   \rm html.lock

    popd

endif

#### Send off the sinex products
if( $ldm == "Y" ) then 
   pushd ../products
      csh ../control/sh_gzip_ts ${ts}
      ssh -n ldm@everest.mit.edu "cd /net/chandler/raid9/tah/ACC_PBO/products; ~/bin/sh_pqinsert *.${ts}"
#     ssh -n ldm@everest.mit.edu "cd /net/everest/raid6/tah/PBO_products; ~/bin/pqinsert *.${ts}"
#     ssh -n ldm@everest.mit.edu "cd /net/everest/raid6/tah/PBO_products; ~/bin/sh_pqinsert *.${ts}"
#    csh ../control/sh_ftp_pbo $ts
   popd
endif


#### See if we will send summary
if( $mailto != "N" ) then
   pushd ../control
   csh sh_summary -f $logf -m $mailto
   popd
endif





 

 


