#!/bin/csh -f
#
# PBO Shell script for processing Reprocessed results by CWU and NMT
# and USGS if available.
#
if( $#argv == 0 ) then
   grep '^## ' $0 | awk '{print substr($0,3)}'
# Here are the options
## Usage: PBO_repro.cmd <options> 
## where the following options are avaiable
##  -d yr day  where yr and day are to processed e.g. 1997 153
##  -r day     where day is number of days before current date
##  -g week num   Group processing for Start Week and number of weeks
##  -m mailto  will invoke summary generation and sending of summary email 
##  -ldm       Put results into LDM queue
##  -ts        Make ts but only with -g option
##  -htog      Re-run htoglb (and hfupd)
##  -update    Set to re-do and update existing solutons
##  -nostat    Set to skip reporting bad station comparison in log and summary
##
## Script run from <proc_dir>/control directory
##
   exit

endif
setenv INSTITUTE MIT
# Now set up defaults
set mailto    = 'N'
set ldm       = 'N'
set OK        = 'N'
set fa        = '/data30/ftp/pub/incoming/ACC_PBO/'
set htog      = 'N'
set update    = 'N'
set ts        = 'N' 
set go        = 'N' 
set nostat    = 'N'
#
# Now read the arguments
foreach a ($argv)
switch($a)
    case -d:
        set yr = $argv[2]
        set doy = $argv[3]

#       Get the gpsweek
        set jd   = `doy $yr $doy | tail -3 | head -1 | awk '{print $8}'`
        set sgpsw = `doy $jd | tail -2 | head -1 | awk '{print $3}'`
        set sgpsd = `doy $jd | tail -2 | head -1 | awk '{print substr($7,1,1)}'`
        set egpsw = $sgpsw
        set egpsd = $sgpsd
        set OK = 'Y'

        breaksw
    case -r:
        set dd = $argv[2]

#       Now get the day number to process
        set jd = `doy | tail -3 | head -1 | awk '{print int($10)}'`
        @ jd = $jd - $dd
        set sgpsw = `doy $jd | tail -2 | head -1 | awk '{print $3}'`
        set sgpsd = `doy $jd | tail -2 | head -1 | awk '{print substr($7,1,1)}'`
        set egpsw = $sgpsw
        set egpsd = $sgpsd
        set OK = 'Y'
        breaksw
    case -g:
        set sgpsw = $argv[2]
        set num = $argv[3]
        set egpsw = `echo $sgpsw $num | awk '{printf("%d",$1+$2-1)}'`
        set sgpsd = 0
        set egpsd = 6
        set OK = 'Y'
        set go = 'Y' 
        breaksw
    case -m*:
        set mailto = $argv[2]
        breaksw
    case -ldm:
        set ldm = "Y"
        breaksw
    case -h*:
        set htog = "Y"
        breaksw
    case -u*:
        set update = "Y"
        breaksw
    case -n*:
        set nostat = "Y"
        breaksw
    default:
#       echo Unknown option $a
#       grep '^## ' $0 | awk '{print substr($0,3)}'
#       exit

endsw
shift
end

if( $OK == 'N' ) then
   echo "Error: No times passed, use -r -d -g option to set dates"
   exit
endif

# Set email test on disk usage:
set esent = N
# Check we have enough disk
set diskOK = N
while ( $diskOK == N )
#  Just check current directory (all processing here).
   set dfree = `df -k . ../PBO_products | grep raid | awk '{printf("%6.1f\n", $4/(1024*1024))}'`
   set diskOK = `echo $dfree | awk '{if( $1 < 5.0 || $2 < 5.0 ) {print "N"} else {print "Y"}}'`
   if( $diskOK == N ) then
      if( $esent == N  ) then
         set subj = `echo $gpsw $gpsd $dfree | awk '{printf("PBO REPRO low disk Processing %4.4dW %1dD, Free %6.1f Gbyte",$1,$2,$3)}'`
         mail -s "$subj" tah@mit.edu <<!
Not enough disk space Free $dfree GB
!

         set esent = Y
      endif
      exit
   endif
end

# Initialize arrays to contain names of files updated
set com_upf = ''
set nmt_upf = ''
set cwu_upf = ''

# OK Start looping over days and weeks
set gpsw = $sgpsw
set gpsd = $sgpsd
while ( $gpsw <= $egpsw ) 
#  If we are looping over weeks then egpsd is 6
   set gpsw = `echo $gpsw | awk '{printf("%4.4d",$1)}'`
   while ( $gpsd <= $egpsd )

#     If we are not updating see if solution exist
      if( $update == 'N' ) then
          if( -e ../COM/com${gpsw}${gpsd}.e.org ) then
#            Soution exits; skip
             echo "No update solution and ../COM/com${gpsw}${gpsd}.e.org  exists; SKIP"
             goto skipall
          endif
      endif
#
      set ts = `date +"%Y%m%d%H%M%S"`
#     OK Ready to go
      set logf = PBO_REP_${gpsw}${gpsd}.log

#      echo $gpsw $gpsd $ts
#      goto skipall

      echo "Creating $logf"
      echo "--------------------------------------------------" >! $logf
      echo -n "++ LOG UPDATE ++ " >> $logf
      date >> $logf
      echo "--------------------------------------------------" >> $logf
      echo "PRODUCT TAG "$ts >> $logf
      echo "MAILTO      "$mailto " LDM? "$ldm >> $logf

# OK See what files are out there to re-process
# Set the times we need
      set jd   = `doy ${gpsw}W $gpsd | tail -3 | head -1 | awk '{print $8}'`
      set yr   = `doy $jd | tail -3 | head -1 | awk '{print substr($2,1,4)}'`
      set yr2  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,3,2)}'`
      set mth  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,6,2)}'`
      set dom  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,9,2)}'`
      set doy  = `doy $jd | tail -3 | head -1 | awk '{print $6}'`
      set mjd  = `doy $yr $doy | tail -3 | head -1 |awk '{print int($10)}'`

#     Now do the invidual solutions
#################################################################################################################################################################################
      cd ../NMT

      set DIR = "NMT"

      echo "Procesing ${DIR} " >> ../control/$logf

#     Search for the .e. repro files
      set ftpfs = `ls ${fa}/${DIR}/nmt${gpsw}${gpsd}*.e.snx*`
      set nftp = `echo $ftpfs | wc -w`
      if( $nftp > 0 ) then
#         Copy the files to ${DIR}_snx area for procesing
          set ftpfs = `ls ${fa}/${DIR}/nmt${gpsw}${gpsd}*.e.*`
          echo "Moving $ftpfs to ../${DIR}_snx"  >> ../control/$logf
          \mv -f $ftpfs ../${DIR}_snx/ 
      endif

#     Now check the status of the files in ${DIR}_snx and ${DIR}_glb
      if( $htog == 'Y' ) then
          \rm ../${DIR}_glbf/h${gpsw}${gpsd}*.e.gls
      endif

      set fs = `ls -rt ../${DIR}_snx/nmt${gpsw}${gpsd}*.e.* ../${DIR}_glbf/h${gpsw}${gpsd}*.e.*`
      if( $#fs == 0 ) then
#        No data found for this gpsw/gpsd value.  Skip out
         echo "NMT solution not found: ${gpsw} ${gpsd} SKIPALL"
         goto skipall
#         exit
      endif
      set lastfs = $fs[$#fs]

#     See if last is gls file (in which case we can just process as is)
      set ext = $lastfs:e
      set type = 'repro'
      set series = e
      if( $ext != "gls" ) then
#        We more recent snx files that need to be processed. Check each
#        file type
         set fs = `ls -rt ../${DIR}_snx/nmt${gpsw}${gpsd}*.e.snx*`
         set lastfs = $fs[$#fs]
         set ext = $lastfs:e
         if( $ext == 'gz' ) then
            gunzip -f $lastfs
         endif
         set fs = `ls -rt ../${DIR}_snx/nmt${gpsw}${gpsd}*.e.snx`
         echo "Running htoglb on $fs" >> ../control/$logf
# MOD TAH 140622: Added translation explicity to be consistemt with CWU
         htoglb ../${DIR}_glbf/ '' -n=GPSW -f=nmt.e -d=rt -e -m=1024 $fs >>  ../control/$logf
         hfupd -s ../control/station.info ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.e.gls >>  ../control/$logf
      endif

#### MOD TAH 131114: See if we need to add the .c. supplemental run to these
#### MOD TAH 131205: Removed not needed with NMT repro.
#     if( $htog == 'Y' ) then
#         \rm ../${DIR}_glbf/*${gpsw}${gpsd}*.c.gls
#     endif

#     set fs = `ls -rt ../${DIR}_snx/nmt${gpsw}${gpsd}*.c.* ../${DIR}_glbf/h${gpsw}${gpsd}*.c.*`
#     if( $#fs == 0 ) then
#        echo "No c-file data found for this gpsw/gpsd value.  " >> ../control/$logf
#     else
#        set lastfs = $fs[$#fs]

#        See if last is gls file (in which case we can just process as is)
#        set ext = $lastfs:e
#        if( $ext != "gls" ) then
#           We more recent snx files that need to be processed. Check each
#           file type
#           set fs = `ls -rt ../${DIR}_snx/nmt${gpsw}${gpsd}*.c.snx*`
#           set lastfs = $fs[$#fs]
#           set ext = $lastfs:e
#           if( $ext == 'gz' ) then
#              gunzip -f $lastfs
#           endif
#           set fs = `ls -rt ../${DIR}_snx/nmt${gpsw}${gpsd}*.c.snx`
#           echo "Running htoglb on $fs" >> ../control/$logf
#           htoglb ../${DIR}_glbf/ '' -n=GPSW -f=nmt.c -d=rt -e -m=1024 $fs >>  ../control/$logf
#           hfupd -s ../control/station.info -cwu  ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.c.gls >>  ../control/$logf
#         endif
#     endif

#### END TAH 131114:


####  OK: Now we can re-run this day.
      set l = $series ; set lm = $l
      \rm nmt${gpsw}${gpsd}.${l}.* >&! /dev/null 
      ls ../${DIR}_glbf/h${gpsw}${gpsd}_1200_nmt.e.gls | awk '{print $1,"  0.70"}' >! nmt${gpsw}${gpsd}.${l}.gdl
#
#     Run globk to combine
      globk 6  nmt${gpsw}${gpsd}.${l}.prt nmt${gpsw}${gpsd}.${l}.log nmt${gpsw}${gpsd}.${l}.gdl ../tables/globk_rep.cmd REPRO >&! /dev/null
      set nmt_upf = ( $nmt_upf nmt${gpsw}${gpsd}.${l}.org )
      set NMT_sites = `grep 'X coordin' nmt${gpsw}${gpsd}.${l}.org | wc -l`
      echo " $NMT_sites sites found in ../NMT/nmt${gpsw}${gpsd}.${l}.org" >> ../control/$logf

      set ${DIR}_tot = `grep ' X coordinate  (m)' nmt${gpsw}${gpsd}.${l}.org | grep -v '_X' | wc -l`
      set ${DIR}_xps = `grep ' X coordinate  (m)' nmt${gpsw}${gpsd}.${l}.org | grep '_X' |  wc -l`

#     Save the sinex file from the combined run
      if( ! -e ../${DIR}_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.${l}.snx ) then
         gzip -df ../${DIR}_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.${l}.snx.gz 
      endif
      \cp -p ../${DIR}_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.${l}.snx ../products/nmt${gpsw}${gpsd}.${type}_loose.snx.${ts}

# MOD TAH 131115: Copy over the .c. version supplemental loose snx to products
      if( ! -e ../${DIR}_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.c.snx ) then
         gzip -df ../${DIR}_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.c.snx.gz 
      endif
      if ( -e ../${DIR}_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.c.snx ) then
          \cp -p ../${DIR}_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.c.snx ../products/nmt${gpsw}${gpsd}.reprc_loose.snx.${ts}
      endif

      glbtosnx ../products '' nmt${gpsw}${gpsd}.${l}.glb.CON nmt${gpsw}${gpsd}.${type}_nam08.snx.${ts}
      \rm nmt${gpsw}${gpsd}.?.glb.CON 

      gzip -f ../${DIR}_snx/*${gpsw}${gpsd}*.e.snx

#################################################################################################################################################################################
#     Now do CWU
      cd ../CWU

      set DIR = "CWU"

      echo "Procesing ${DIR} " >> ../control/$logf

#     Search for the .e. repro files
      set ftpfs = `ls ${fa}/${DIR}/???${gpsw}${gpsd}*.e.snx*`
      set nftp = `echo $ftpfs | wc -w`
      if( $nftp > 0 ) then
#         Copy the files to ${DIR}_snx area for procesing
          set ftpfs = `ls ${fa}/${DIR}/???${gpsw}${gpsd}*.e.*`
          echo "Moving $ftpfs to ../${DIR}_snx"  >> ../control/$logf
          \mv -f $ftpfs ../${DIR}_snx/ 
      endif

#     Now check the status of the files in ${DIR}_snx and ${DIR}_glb
      if( $htog == 'Y' ) then
          \rm ../${DIR}_glbf/h${gpsw}${gpsd}*.e.gls
      endif
      set fs = `ls -rt ../${DIR}_snx/CWU${gpsw}${gpsd}*.e.* ../${DIR}_glbf/h${gpsw}${gpsd}*.e.*`
      if( $#fs == 0 ) then
#        No data found for this gpsw/gpsd value.  Skip out
         echo "CWU solution not found: ${gpsw} ${gpsd} SKIPALL"
         goto skipall
#         exit
      endif
      set lastfs = $fs[$#fs]
#     See if last is gls file (in which case we can just process as is)
      set ext = $lastfs:e
      set type = 'repro'
      set series = e
      if( $ext != "gls" ) then
#        We more recent snx files that need to be processed. Check each
#        file type
         set fs = `ls -rt ../${DIR}_snx/CWU${gpsw}${gpsd}*.e.snx*`
         set lastfs = $fs[$#fs]
         set ext = $lastfs:e
         if( $ext == 'gz' ) then
            gunzip -f $lastfs
         endif
         set fs = `ls -rt ../${DIR}_snx/CWU${gpsw}${gpsd}*.e.snx`
         echo "Running htoglb on $fs" >> ../control/$logf
# MOD TAH 140620: Add the translation to CWU solutions.
         htoglb ../${DIR}_glbf/ '' -n=GPSW -f=cwu.e -d=rt -e -m=1024 $fs >>  ../control/$logf
         echo "HFUPD START `date`" >>  ../control/$logf
         hfupd -s ../control/station.info -cwu  ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.e.gls >>  ../control/$logf
         echo "HFUPD END   `date`" >>  ../control/$logf
      endif

####  OK: Now we can re-run this day.
      set l = $series ; set lm = $l
      \rm cwu${gpsw}${gpsd}.${l}.* >&! /dev/null 
      ls ../${DIR}_glbf/h${gpsw}${gpsd}_1200_cwu.e.gls | awk '{print $1,"  4.80"}' >! cwu${gpsw}${gpsd}.${l}.gdl
#
#     Run globk to combine
      globk 6  cwu${gpsw}${gpsd}.${l}.prt cwu${gpsw}${gpsd}.${l}.log cwu${gpsw}${gpsd}.${l}.gdl ../tables/globk_rep.cmd REPRO >&! /dev/null
      echo "GLOBK CWU END   `date`" >>  ../control/$logf
      set cwu_upf = ( $cwu_upf cwu${gpsw}${gpsd}.${l}.org )

      set CWU_sites = `grep 'X coordin' cwu${gpsw}${gpsd}.${l}.org | wc -l`
      echo " $CWU_sites sites found in ../CWU/cwu/${gpsw}${gpsd}.${l}.org" >> ../control/$logf

      set ${DIR}_tot = `grep ' X coordinate  (m)' cwu${gpsw}${gpsd}.${l}.org | grep -v '_X' | wc -l`
      set ${DIR}_xps = `grep ' X coordinate  (m)' cwu${gpsw}${gpsd}.${l}.org | grep '_X' |  wc -l`

#     Save the sinex file from the combined run
      if( ! -e ../${DIR}_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.${l}.snx ) then
         gzip -df ../${DIR}_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.${l}.snx.gz 
      endif
      \cp -p ../${DIR}_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.${l}.snx ../products/cwu${gpsw}${gpsd}.${type}_loose.snx.${ts}
      glbtosnx ../products '' cwu${gpsw}${gpsd}.${l}.glb.CON cwu${gpsw}${gpsd}.${type}_nam08.snx.${ts}
      \rm cwu${gpsw}${gpsd}.?.glb.CON 

      gzip -f ../${DIR}_snx/*${gpsw}${gpsd}*.e.snx


#     Go and repro of combined PBO product
#################################################################################################################################################################################
      cd ../COM
#
#     See what level of file is around
      set hfs = `ls -tr ../???_glbf/h${gpsw}${gpsd}_1200_???.e.gls`
 
      echo "COMBINED SOLUTION $type $l" >> ../control/$logf
      \rm com${gpsw}${gpsd}.${l}.* >&! /dev/null 

#     Weights here are sqrt(2) times each center to keep sigma ~correct
      ls ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.e.gls     | awk '{print $1 "  1.4"}' >! com${gpsw}${gpsd}.${l}.gdl
      ls ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.e.gls     | awk '{print $1 "  9.6"}' >> com${gpsw}${gpsd}.${l}.gdl
      globk 6  com${gpsw}${gpsd}.${l}.prt com${gpsw}${gpsd}.${l}.log com${gpsw}${gpsd}.${l}.gdl ../tables/globk_rep.cmd REPRO >&! /dev/null
      echo "GLOBK COM END   `date`" >>  ../control/$logf
      set com_upf = ( $com_upf com${gpsw}${gpsd}.${l}.org )

      set COM_tot = `grep ' X coordinate  (m)' com${gpsw}${gpsd}.${l}.org | grep -v '_X' |  wc -l`
      set COM_xps = `grep ' X coordinate  (m)' com${gpsw}${gpsd}.${l}.org | grep '_X' |  wc -l`

## Save the sinex file from the combinaed run
      glbtosnx ../products '' com${gpsw}${gpsd}.${l}.glb     pbo${gpsw}${gpsd}.${type}_loose.snx.${ts}
      glbtosnx ../products '' com${gpsw}${gpsd}.${l}.glb.CON pbo${gpsw}${gpsd}.${type}_nam08.snx.${ts}
      \rm com${gpsw}${gpsd}.${l}.glb.CON 
      echo "GLBTOSNX END   `date`" >>  ../control/$logf

#########################################################################################################################################################
#     Remake the rms files
      set tx = `date +"%Y%m%d%H%M%S"`
      sh_exglk -f com${gpsw}${gpsd}.${l}.org -pos t${tx}.pos
      set sites = `grep -h '^ ' ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.e.rms ../CWU_snx/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.e.rms | awk '{print $1}' | sort -u`
      set rmsf = ../COM_snx/com${gpsw}${gpsd}.${yr}${mth}${dom}.${l}.rms
      echo "RMS File from " `ls ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.e.rms ../CWU_snx/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.e.rms` >! $rmsf
      echo "Format Version : 1.1.0" >> $rmsf
      echo "Release Date   : $ts" >> $rmsf
      echo "Start Field Description" >> $rmsf
      echo "Dot#            4-character identifier for a given station" >> $rmsf
      echo "PBO_#           Number 30-sec phase epochs in 24-hours for combined RMS calculation" >> $rmsf
      echo "PRMS            Root-mean-square (RMS) scatter of combined phase residuals, mm" >> $rmsf
      echo "CWU_#           Number 30-sec phase epochs in 24-hours for CWU RMS calculation" >> $rmsf
      echo "CRMS            Root-mean-square (RMS) scatter of CWU phase residuals, mm" >> $rmsf
      echo "NMT_#           Number 30-sec phase epochs in 24-hours for NMT or BSL (prior to Feb 2006) RMS calculation" >> $rmsf
      echo "NRMS            Root-mean-square (RMS) scatter of NMT or BSL phase residuals, mm" >> $rmsf
      echo "A               Coefficient from model fit RMS^2(elev) = A^2 + B^2/sin(elev)^2 where elev is elevation angle, mm" >> $rmsf
      echo "B               Coefficient from model fit, mm" >> $rmsf
      echo "GPSW            GPS Week for 24-hour processing day" >> $rmsf
      echo "D               GPS Day of week for 24-hour processing day" >> $rmsf
      echo "YYYYMMDD        Year, month, day of month for 24-hour processing day" >> $rmsf
      echo "End Field Description " >> $rmsf
      echo "*Dot#  PBO_#   PRMS    CWU_#   CRMS     NMT_#  NRMS        A      B GPSW D YYYYMMDD" >> $rmsf
#
#     Extract lines for each site.  
      foreach s (`echo $sites`)
          set nmtstat = `grep -h $s ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.e.rms |  awk '{n=n+$2}{r=r+$3}{a=a+$4}{b=b+$5} END {if ( NR > 0 ) {print n/NR,r/NR,a/NR,b/NR} else {print "No"}}'` 
          set cwustat = `grep -h $s ../CWU_snx/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.e.rms |  awk '{n=n+$2}{r=r+$3} END {if ( NR > 0 ) {print n*10/NR,r/NR} else {print "No"}}'`
          if ( $nmtstat[1] == No ) then  
              echo $s $cwustat ${gpsw} ${gpsd} ${yr}${mth}${dom} | awk '{printf(" %s  %5d %6.1f    %5d %6.1f         -     -       -      -  %4.4d %1d %8d\n",$1,$2,$3,$2,$3,$4,$5,$6)}' >> $rmsf 
          else if ( $cwustat[1] == No ) then
              echo $s $nmtstat ${gpsw} ${gpsd} ${yr}${mth}${dom} | awk '{printf(" %s  %5d %6.1f        -     -      %5d %6.1f  %6.1f %6.1f %4.4d %1d %8d\n",$1,$2,$3,$2,$3,$4,$5,$6,$7,$8)}'>> $rmsf
          else
              echo $s $cwustat $nmtstat ${gpsw} ${gpsd} ${yr}${mth}${dom} | awk '{printf(" %s  %5d %6.1f    %5d %6.1f     %5d %6.1f  %6.1f %6.1f %4.4d %1d %8d\n",$1,($2+$4)/2,($3+$5)/2,$2,$3,$4,$5,$6,$7,$8,$9,$10)}'>> $rmsf
          endif 
      end 
      echo "RMS end $rmsf   `date`" >>  ../control/$logf

      if( $nostat == 'Y' ) then
          grep 'POS S' ../COM/com${gpsw}${gpsd}.${l}.org  | awk '{print "*BC "substr($0,17)}' >> ../control/${logf}
          grep 'POS S' ../NMT/nmt${gpsw}${gpsd}.${l}.org  | awk '{print "*BB "substr($0,17)}' >> ../control/${logf}
          grep 'POS S' ../CWU/cwu${gpsw}${gpsd}.${l}.org  | awk '{print "*BW "substr($0,17)}' >> ../control/${logf}
          goto NOSTAT
      endif

#     Generate the statistics
      ls ../???_glbf/h${gpsw}${gpsd}_1200_???.e.gls >! h${gpsw}${gpsd}.e.gdl
      glist h${gpsw}${gpsd}.e.gdl  h${gpsw}${gpsd}.e.glist >> ../control/$logf
      ls ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.e.gls >! a${tx}.gdl
      glist a${tx}.gdl | grep 'P$' | awk '{print $8}' | sort >! a${tx}.lst
      # Get the date of this comparison
      set compdate = `glist a${tx}.gdl | grep '^ ... .. ..     1 ' | awk '{printf("%4.4d %2.2d %2.2d",$1+2000,$2,$3)}'`
      set compweek = `doy $compdate | head -2 | tail -1 | awk '{printf("%4.4dw%1.1dd",$3,$7)}'`    
      ls ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.e.gls >! b${tx}.gdl
      glist b${tx}.gdl | grep 'P$' | awk '{print $8}' | sort >! b${tx}.lst

      echo "*SC Statistics of missing stations for $compdate GPS Week $compweek" >>  ../control/$logf
      echo "*SC      NMT   CWU  COM #    RMS    CWU #    RMS     NMT #    RMS      A      B" >> ../control/$logf
      echo "*SC                          mm              mm               mm      mm     mm" >> ../control/$logf           
      set nmtlst = `comm -3 a${tx}.lst b${tx}.lst | awk -F '\t' '{if( NF == 1 ) {print substr($1,1,4)}}'`
      set cwulst = `comm -3 a${tx}.lst b${tx}.lst | awk -F '\t' '{if( NF == 2 ) {print substr($2,1,4)}}'`
      set cnt = 0 
      echo "Checking nmtlst for `echo $nmtlst | wc -w` sites"
      foreach s (`echo $nmtlst`)
          @ cnt = $cnt + 1
          grep $s $rmsf | awk -v cnt=$cnt '{printf("*SC %4d %s       %s\n",cnt, $1, substr($0,8))}' >> ../control/$logf
      end
      if ( $cnt > 0 ) echo " " >> ../control/$logf
      set cnt = 0 
      echo "Checking cwulst for `echo $cwulst | wc -w` sites"
      foreach s (`echo $cwulst`)
          @ cnt = $cnt + 1
          grep $s $rmsf | awk -v cnt=$cnt '{printf("*SC %4d       %s %s\n",cnt, $1, substr($0,8))}' >> ../control/$logf
      end
      \rm h${gpsw}${gpsd}.e.gdl h${gpsw}${gpsd}.e.glist a${tx}.gdl a${tx}.lst b${tx}.gdl b${tx}.lst
      echo "STATISTICS END   `date`" >>  ../control/$logf

      \cp -p ../COM_snx/com${gpsw}${gpsd}.${yr}${mth}${dom}.${l}.rms ../products/pbo${gpsw}${gpsd}.${type}_nam08.rms.${ts}
#
#     Check for site coordinates that we do not have and those that do no match aprioiri
      set apfs = `grep -i "APRIORI file   :"  ../COM/com${gpsw}${gpsd}.e.org | awk '{print $4}'`
#
      set sites = `grep '^ ' t${tx}.pos | grep -v '_X' | awk '{print substr($13,1,8)}' | sort -u`
# Now check the quality of each site position.  
      grep 'POS S' com${gpsw}${gpsd}.${l}.org  | awk '{print "*BC "substr($0,17)}' >> ../control/${logf}
      set badout = 0
      set badlist = ""
      foreach s ( `echo $sites` )
#
          set s4 = `echo $s | awk '{print substr($1,1,4)}'`
#         See if this site is in apriori files.
#         Chi[1] 2-D (mm), Chi[2] dH mm; chi[3] = 2D sigma Normalized, chi[4] height normalized; chi[5] 3-D normalized
          set chi = `grep $s t${tx}.pos | awk '{print sqrt(($3^2+$4^2)/2), sqrt($10^2), sqrt((($3/$7)^2+($4/$8)^2)/2), sqrt(($10/$12)^2), sqrt((($3/$7)^2+($4/$8)^2+($10/$12)^2)/3)}'` 
#
#         See if site is in apriori files
          set inapfs = `grep $s $apfs | wc -l`
          if( $inapfs > 0 ) then
#             Site is in aprori files; see if anomalous: more than 4-sigma from apriori
              set bad = `echo $chi[5] | awk '{if( $1 > 4 ) {print "1"} else {print "0"}}'`
              if ( $bad == 1 ) then
                 if ( $badout == 0 ) then
                    echo "*BC Sites with large position adjustments from combined solution" >> ../control/${logf}
                    echo "*BC Num     Site     dE    +-      dN     +-    dH     +-      COM #    RMS    CWU #    RMS     NMT #    RMS " >> ../control/${logf}
                 endif
                 @ badout = $badout + 1; set badlist = `echo $badlist $s`
                 echo $badout | awk '{printf("*BC %3d",$1)}' >> ../control/${logf}
                 grep $s  t${tx}.pos | awk '{printf(" %9s %6.1f %6.1f %6.1f %6.1f %6.1f %6.1f ",$13,$3,$7,$4,$8,$10,$12)}' >> ../control/${logf}
                 grep $s4 $rmsf | awk '{printf(" %s",substr($0,6,48))}' >> ../control/${logf} 
                 echo "" >> ../control/${logf} 
              endif
          else
#             Add site to Updated file
              echo "* Site added "`date` >> ../tables/PBO_new.apr 
# MOD TAH 051128: Make sure sigma is good before updating.
              grep Apr. com${gpsw}${gpsd}.${l}.org | grep $s | awk '{if ( $12 < 0.01 ) {print substr($0,5)}}' >> ../tables/PBO_new.apr
          endif
      end
#

###   Echo number of sites
      echo "*NUM " $COM_tot $COM_xps $NMT_tot $NMT_xps $CWU_tot $CWU_xps >> ../control/${logf}
      echo "COMPARE END   `date`" >>  ../control/$logf

#     Now see how all the bad sites compare
      set badlist = `echo $badlist | awk '{for (i=1; i<=NF; i++) printf " %s\n", $i}' | sort -u`
      set files = `ls ../[CN]??/???${gpsw}${gpsd}.${l}.org`
      echo "Checking badlist for `echo $badlist | wc -w` sites in $files"
      foreach s (`echo $badlist`)
         grep "^  [ 123]" $files | egrep -v 'coordinate|XYZ' | grep $s | awk '{print "*BA ",$0}' >> ../control/${logf}
         echo "*BA +++" >> ../control/${logf}
      end
      echo "BADLIST END   `date`" >>  ../control/$logf
#################################################################################################################################################################################
#     Now go back and do the statistics for the NMT and CWU solutions
      cd ../NMT
##### Run statistics
      sh_exglk -f nmt${gpsw}${gpsd}.${l}.org -pos t${tx}.pos
      set sites = `grep '^ ' t${tx}.pos | grep -v '_X' | awk '{print substr($13,1,8)}'`
#     Now check the quality of each site position.  
      grep 'POS S' nmt${gpsw}${gpsd}.${l}.org  | awk '{print "*BB "substr($0,17)}' >> ../control/${logf}
      grep BAD  nmt${gpsw}${gpsd}.${l}.log | awk '{printf("*BB Gross Error %s dXYZ %10.3f %10.3f %10.3f m\n",$6,$10,$11,$12)}' >> ../control/${logf}
      set badout = 0
      foreach s ( `echo $sites` )
#
          set s4 = `echo $s | awk '{print substr($1,1,4)}'`
#         See if this site is in apriori files.
#         Chi[1] 2-D (mm), Chi[2] dH mm; chi[3] = 2D sigma Normalized, chi[4] height normalized; chi[5] 3-D normalized
          set chi = `grep $s t${tx}.pos | awk '{print sqrt(($3^2+$4^2)/2), sqrt($10^2), sqrt((($3/$7)^2+($4/$8)^2)/2), sqrt(($10/$12)^2), sqrt((($3/$7)^2+($4/$8)^2+($10/$12)^2)/3)}'` 
#
#         See if site is in apriori files
          set bad = `echo $chi[5] | awk '{if( $1 > 4 ) {print "1"} else {print "0"}}'`
          if ( $bad == 1 ) then
             if ( $badout == 0 ) then
                echo "*BB Sites with large position adjustments from combined solution" >> ../control/${logf}
                echo "*BB Num     Site     dE    +-      dN      +-    dH     +-     COM #    RMS    CWU #    RMS     NMT #    RMS" >> ../control/${logf}
             endif
             @ badout = $badout + 1; set badlist = `echo $badlist $s`
             echo $badout | awk '{printf("*BB %3d",$1)}' >> ../control/${logf}
             grep $s  t${tx}.pos | awk '{printf(" %9s %6.1f %6.1f %6.1f %6.1f %6.1f %6.1f ",$13,$3,$7,$4,$8,$10,$12)}' >> ../control/${logf}
             grep $s4 $rmsf | awk '{printf(" %s",substr($0,6,48))}' >> ../control/${logf}
             echo "" >> ../control/${logf} 

          endif
      end
      echo "NMT STATS END   `date`" >>  ../control/$logf

      cd ../CWU
####  Statistics for CWU
      sh_exglk -f cwu${gpsw}${gpsd}.${l}.org -pos t${tx}.pos
      set sites = `grep '^ ' t${tx}.pos | grep -v '_X' | awk '{print substr($13,1,8)}'`
#     Now check the quality of each site position.  
      grep 'POS S' cwu${gpsw}${gpsd}.${l}.org  | awk '{print "*BW "substr($0,17)}' >> ../control/${logf}
      grep BAD  cwu${gpsw}${gpsd}.${l}.log | awk '{printf("*BW Gross Error %s dXYZ %10.3f %10.3f %10.3f m\n",$6,$10,$11,$12)}' >> ../control/${logf}
      set badout = 0
      foreach s ( `echo $sites` )
#
          set s4 = `echo $s | awk '{print substr($1,1,4)}'`
#         See if this site is in apriori files.
#         Chi[1] 2-D (mm), Chi[2] dH mm; chi[3] = 2D sigma Normalized, chi[4] height normalized; chi[5] 3-D normalized
          set chi = `grep $s t${tx}.pos | awk '{print sqrt(($3^2+$4^2)/2), sqrt($10^2), sqrt((($3/$7)^2+($4/$8)^2)/2), sqrt(($10/$12)^2), sqrt((($3/$7)^2+($4/$8)^2+($10/$12)^2)/3)}'` 
#
#         See if site is in apriori files
          set bad = `echo $chi[5] | awk '{if( $1 > 4 ) {print "1"} else {print "0"}}'`
          if ( $bad == 1 ) then
             if ( $badout == 0 ) then
                echo "*BW Sites with large position adjustments from combined solution" >> ../control/${logf}
                echo "*BW Num     Site     dE    +-      dN      +-    dH     +-     COM #    RMS    CWU #    RMS     NMT #    RMS" >> ../control/${logf}
             endif
             @ badout = $badout + 1; set badlist = `echo $badlist $s`
             echo $badout | awk '{printf("*BW %3d",$1)}' >> ../control/${logf}
             grep $s  t${tx}.pos | awk '{printf(" %9s %6.1f %6.1f %6.1f %6.1f %6.1f %6.1f ",$13,$3,$7,$4,$8,$10,$12)}' >> ../control/${logf}
             grep $s4 $rmsf | awk '{printf(" %s",substr($0,6,48))}' >> ../control/${logf}
             echo "" >> ../control/${logf} 

          endif
      end
      echo "CWU STATS END   `date`" >>  ../control/$logf
# Skip to here if now statistics
NOSTAT:

      #### Send off the sinex products
      pushd ../products
         csh ../control/sh_gzip_ts ${ts}
         if( $ldm == "Y" ) then 
            ssh -n ldm@everest.mit.edu "cd /net/chandler/raid9/tah/ACC_PBO/PBO_products; ~/bin/sh_pqinsert *.${ts}"
         endif
      popd
      echo "GZIP END   `date`" >>  ../control/$logf

      #### See if we will send summary
      if( $mailto != "N" ) then
         pushd ../control
         csh sh_summary -f $logf -m $mailto
         popd
      endif
      echo "SUMMARY END   `date`" >>  ../control/$logf

skipall:

##### END OF DAY LOOP: increment day
      @ gpsd = $gpsd + 1
##    go back to control directory
      cd ../control

   end

## Update the time series for the week

## END OF WEEK LOOP
#   @ gpsw = $gpsw + 1
   set gpsw = `echo $gpsw | awk '{printf("%d",$1+1)}'`
   set gpsd = 0

end

## See if we want to update time series and queue them with ldm
if ( $ts == "Y" && $go == "Y" ) then
  csh sh_repro_ts -g $sgpsw $num
  # Now send the tar file
  if( $ldm == "Y" ) then 
     csh sh_pos_tar final '' ldm
   endif
endif
#








