#!/bin/csh -f
#
# PBO Shell script for processing Supplement results from CWU and NMT/BSL ACs
#
# See if arguments passed
if( $#argv == 0 ) then
   grep '^## ' $0 | awk '{print substr($0,3)}'
# Here are the options
## Usage: PBO_supp6.cmd <options> 
## where the following options are avaiable
##  -d yr day  where yr and day are to processed e.g. 1997 153
##  -r day     where day is number of days before current date
##  -m mailto  will invoke summary generation and sending of summary email 
##  -ldm       Pur results into LDM queue
##  -no_hfupd    Don't run hfupd to check site meta data
##  -clear       Clears Binary hfiles and previous log and start again
##
## Script run from <proc_dir>/control directory
##
   exit

endif
setenv INSTITUTE MIT
# Now set up defaults
set hfupd     = 'Y'
set clear     = 'N'
set mailto    = 'N'
set ldm       = 'N'
set srcd = '/data30/ftp/pub/incoming/ACC_PBO/'
set ts = `date +"%H%M%S"`
#
# Now read the arguments
foreach a ($argv)
switch($a)
    case -d:
        set yr = $argv[2]
        set doy = $argv[3]

#       Get the gpsweek
        set jd   = `doy $yr $doy | tail -3 | head -1 | awk '{print $8}'`
        set gpsw = `doy $jd | tail -2 | head -1 | awk '{print $3}'`
        set gpsd = `doy $jd | tail -2 | head -1 | awk '{print substr($7,1,1)}'`
        set yr   = `doy $jd | tail -3 | head -1 | awk '{print substr($2,1,4)}'`
        set yr2  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,3,2)}'`
        set mth  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,6,2)}'`
        set dom  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,9,2)}'`
        set doy  = `doy $jd | tail -3 | head -1 | awk '{print $6}'`
        set mjd  = `doy $yr $doy | tail -3 | head -1 |awk '{print int($10)}'`
        set jdn  = `doy | tail -3 | head -1 | awk '{print int($10)}'`
        @ dd = $jdn - $mjd
        breaksw
    case -r:
        set dd = $argv[2]

#       Now get the day number to process
        set jd = `doy | tail -3 | head -1 | awk '{print int($10)}'`
        @ jd = $jd - $dd
        set gpsw = `doy $jd | tail -2 | head -1 | awk '{print $3}'`
        set gpsd = `doy $jd | tail -2 | head -1 | awk '{print substr($7,1,1)}'`
        set yr   = `doy $jd | tail -3 | head -1 | awk '{print substr($2,1,4)}'`
        set yr2  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,3,2)}'`
        set mth  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,6,2)}'`
        set dom  = `doy $jd | tail -3 | head -1 | awk '{print substr($2,9,2)}'`
        set doy  = `doy $jd | tail -3 | head -1 | awk '{print $6}'`
       
        breaksw
    case -no_h*:
        set hfupd = "N"
        breaksw
    case -cl*:
        set clear = "Y"
        breaksw
    case -m*:
        set mailto = $argv[2]
        breaksw
    case -ldm:
        set ldm = "Y"
        breaksw
    default:
#       echo Unknown option $a
#       grep '^## ' $0 | awk '{print substr($0,3)}'
#       exit

endsw
shift
end

# Set email test on disk usage:
set esent = N
# Check we have enough disk
set diskOK = N
while ( $diskOK == N )
   set dfree = `df -k . ../PBO_products | grep raid | awk '{printf("%6.1f\n", $4/(1024*1024))}'`
   set diskOK = `echo $dfree | awk '{if( $1 < 5.0 || $2 < 5.0 ) {print "N"} else {print "Y"}}'`
   if( $diskOK == N ) then
      if( $esent == N  ) then
         set subj = `echo $gpsw $gpsd $dfree | awk '{printf("PBO SUPP6 low disk Processing %4.4dW %1dD, Free %6.1f Gbyte",$1,$2,$3)}'`
         set subj = `echo $gpsw $gpsd $dfree | awk '{printf("PBO SUPP6 low disk Processing %4.4dW %1dD, Free %6.1f %6.1f Gb",$1,$2,$3,$4)}'`
         mail -s "$subj" tah@mit.edu <<!
Not enough disk space Free $dfree GB
!

         set esent = Y
      endif
      sleep 10m
   endif
end

# Adjust the $gpsw
set gpsw = `echo $gpsw | awk '{printf("%04d",$1)}'`
set doy = `echo $doy | awk '{printf("%03d",$1)}'`
# Set up the log file
set logf = PBO_SU6_${gpsw}${gpsd}.log
if( $clear == "Y" ) then
   \rm $logf >&! /dev/null
   \rm ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.f.gls >&! /dev/null
   \rm ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.f.gls >&! /dev/null
   if( -e ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx.gz ) then
       \rm ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx
   endif
   if( -e ${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx ) then
       \rm ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx
   endif

endif
if( ! -e $logf  ) then
   touch $logf
endif
echo "Creating/Updating $logf"
echo "--------------------------------------------------" >> $logf
echo -n "++ LOG UPDATE ++ " >> $logf
date >> $logf
echo "--------------------------------------------------" >> $logf

#
# See if NMT file is already in glbf area
if ( ! -e ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.f.gls ) then
#   See if already in sinex area
    if( ! -e ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx ) then
        if ( -e ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx ) then 
            \mv ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx ../NMT_snx/
            \mv ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.f.rms ../NMT_snx/
           # \mv ${srcd}/NMT/H${yr2}${mth}${dom}_nmtcr.GLX ../NMT_glbf
        else if ( -e ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx.gz ) then 
            \mv ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx.gz ../NMT_snx/
             gzip -d ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx.gz
            \mv ${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.f.rms ../NMT_snx/
          #  \mv ${srcd}/NMT/H${yr2}${mth}${dom}_nmtcr.GLX ../NMT_glbf/
        else
            echo "${srcd}/NMT/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx not available" >>  $logf
        endif
    endif 
    if( -e ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx ) then
#       Convert the sinex to globk binary hfile
        htoglb ../NMT_glbf/ ' ' -n=GPSW -f=nmt.f -d=tr -e -m=1024 ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx >>  $logf
    endif
endif
#

# See if the CWU file is available
# MOD TAH 140123: Test to see if repro (.e.) files are available
set OKR = N
if ( ! -e ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.e.gls ) then
#   See if already in sinex area
    if( ! -e ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.e.snx ) then
        if ( -e ${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.e.snx ) then 
            \mv ${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.e.snx ../CWU_snx/
            \mv ${srcd}/CWU/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.e.rms ../CWU_snx/
        else
            echo "${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.e.snx not available" >>  $logf
        endif
    endif
    if( -e ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.e.snx ) then
#       Convert the sinex to globk binary hfile
        htoglb ../CWU_glbf/ ' ' -n=GPSW -f=cwu.e -d=tr -e -m=1024 ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.e.snx >>  $logf
    endif
endif
if (  -e ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.e.gls ) set OKR = Y 
# Only use .f. file if no REPRO file
if ( ! -e ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.f.gls && $OKR == N ) then
#   See if already in sinex area
    if( ! -e ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx ) then
        if ( -e ${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx ) then 
            \mv ${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx ../CWU_snx/
            \mv ${srcd}/CWU/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.f.rms ../CWU_snx/
        else
            echo "${srcd}/CWU/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx not available" >>  $logf
        endif
    endif
    if( -e ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx ) then
#       Convert the sinex to globk binary hfile
        htoglb ../CWU_glbf/ ' ' -n=GPSW -f=cwu.f -d=tr -e -m=1024 ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx >>  $logf
    endif
endif
#
# MOD TAH 140123: Set the files range either .e. or .[bf]. for CWU
set ty = "[bf]"
if( $OKR == Y ) set ty = "e"
#
# 
# Run hfupd to check the status
if( $hfupd == 'Y' ) then
   echo "HFUPD Check `date`" >> $logf
   if( $OKR == Y ) then
       hfupd -s station.info -cwu  ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.f.gls  ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.e.gls  >>  $logf
   else
       hfupd -s station.info -cwu  ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.f.gls  ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.f.gls  >>  $logf
   endif
   echo "HFUPD Done `date`" >> $logf
endif
 
#########################
# Set the time stamp for these runs

set ts = `date +"%Y%m%d%H%M%S"`
echo "PRODUCT TAG "$ts >> $logf
echo "COMBINED SOLUTION suppl f" >> $logf

#########################
# Move any old suppl products to old products directory
set num_old = `ls ../products/???${gpsw}${gpsd}.s* |& grep -v 'No match' | wc -l`
if( $num_old != 0 ) then
   echo "Removing old products:" >> $logf
   ls ../products/???${gpsw}${gpsd}.s* >> $logf
#   \mv ../products/???${gpsw}${gpsd}.s* ../old_products/
   \rm ../products/???${gpsw}${gpsd}.s* 
endif
#
#  Check list of sites
set tx = `date +"%Y%m%d%H%M%S"`
ls ../???_glbf/h${gpsw}${gpsd}_1200_???.[ef].gls >! h${gpsw}${gpsd}.f.gdl
glist h${gpsw}${gpsd}.f.gdl  h${gpsw}${gpsd}.f.glist >> $logf
grep 'P$' h${gpsw}${gpsd}.f.glist >> $logf

#  Now get the list of sites in the combined set for this day
ls ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.[bf].gls  >! a${tx}.gdl
glist a${tx}.gdl | grep 'P$' | tail -n +4 | awk '{print substr($8,1,4)}' | sort -u >! a${tx}.lst

# Get the date of this comparison
set compdate = `glist a${tx}.gdl | grep '^ ... .. ..     1 ' | awk '{printf("%4.4d %2.2d %2.2d",$1+2000,$2,$3)}'`
set compweek = `doy $compdate | head -2 | tail -1 | awk '{printf("%4.4dw%1.1dd",$3,$7)}'` 

# Get CWU full list   
ls ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.${ty}.gls  >! b${tx}.gdl
glist b${tx}.gdl | grep 'P$' | tail -n +4 | awk '{print substr($8,1,4)}' | sort -u >! b${tx}.lst
#
# Generate the merged RMS file for this day
# Get list of sites
set sites = `grep -h '^ ' ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.[bf].rms ../CWU_snx/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.${ty}.rms | awk '{print $1}' | sort -u`
set rmsf = ../COM_snx/com${gpsw}${gpsd}.${yr}${mth}${dom}.f.rms
echo "RMS File from " `ls ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.[bf].rms ../CWU_snx/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.${ty}.rms` >! $rmsf
echo "Format Version : 1.1.0" >> $rmsf
echo "Release Date   : $ts" >> $rmsf
echo "Start Field Description" >> $rmsf
echo "Dot#            4-character identifier for a given station" >> $rmsf
echo "PBO_#           Number 30-sec phase epochs in 24-hours for combined RMS calculation" >> $rmsf
echo "PRMS            Root-mean-square (RMS) scatter of combined phase residuals, mm" >> $rmsf
echo "CWU_#           Number 30-sec phase epochs in 24-hours for CWU RMS calculation" >> $rmsf
echo "CRMS            Root-mean-square (RMS) scatter of CWU phase residuals, mm" >> $rmsf
echo "NMT_#           Number 30-sec phase epochs in 24-hours for NMT or BSL (prior to Feb 2006) RMS calculation" >> $rmsf
echo "NRMS            Root-mean-square (RMS) scatter of NMT or BSL phase residuals, mm" >> $rmsf
echo "A               Coefficient from model fit RMS^2(elev) = A^2 + B^2/sin(elev)^2 where elev is elevation angle, mm" >> $rmsf
echo "B               Coefficient from model fit, mm" >> $rmsf
echo "GPSW            GPS Week for 24-hour processing day" >> $rmsf
echo "D               GPS Day of week for 24-hour processing day" >> $rmsf
echo "YYYYMMDD        Year, month, day of month for 24-hour processing day" >> $rmsf
echo "End Field Description " >> $rmsf
echo "*Dot#  PBO_#   PRMS    CWU_#   CRMS     NMT_#  NRMS        A      B GPSW D YYYYMMDD" >> $rmsf

#
# Extract lines for each site.  
foreach s (`echo $sites`)
    set nmtstat = `grep -h $s ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.[bf].rms |  awk '{n=n+$2}{r=r+$3}{a=a+$4}{b=b+$5} END {if ( NR > 0 ) {print n/NR,r/NR,a/NR,b/NR} else {print "No"}}'` 
    set cwustat = `grep -h $s ../CWU_snx/cwu${gpsw}${gpsd}.${yr}${mth}${dom}.${ty}.rms |  awk '{n=n+$2}{r=r+$3} END {if ( NR > 0 ) {print n*10/NR,r/NR} else {print "No"}}'`
    if ( $nmtstat[1] == No ) then  
        echo $s $cwustat ${gpsw} ${gpsd} ${yr}${mth}${dom} | awk '{printf(" %s  %5d %6.1f    %5d %6.1f         -     -       -      -  %4.4d %1d %8d\n",$1,$2,$3,$2,$3,$4,$5,$6)}' >> $rmsf 
    else if ( $cwustat[1] == No ) then
        echo $s $nmtstat ${gpsw} ${gpsd} ${yr}${mth}${dom} | awk '{printf(" %s  %5d %6.1f        -     -      %5d %6.1f  %6.1f %6.1f %4.4d %1d %8d\n",$1,$2,$3,$2,$3,$4,$5,$6,$7,$8)}'>> $rmsf
    else
        echo $s $cwustat $nmtstat ${gpsw} ${gpsd} ${yr}${mth}${dom} | awk '{printf(" %s  %5d %6.1f    %5d %6.1f     %5d %6.1f  %6.1f %6.1f %4.4d %1d %8d\n",$1,($2+$4)/2,($3+$5)/2,$2,$3,$4,$5,$6,$7,$8,$9,$10)}'>> $rmsf
    endif 

end 

echo "*SC Statistics of missing stations for $compdate GPS Week $compweek" >>  $logf
echo "*SC      NMT   CWU  COM #    RMS    CWU #    RMS     NMT #    RMS      A      B" >> $logf
echo "*SC                          mm              mm               mm      mm     mm" >> $logf           
set nmtlst = `comm -3 a${tx}.lst b${tx}.lst | awk -F '\t' '{if( NF == 1 ) {print substr($1,1,4)}}'`
set cwulst = `comm -3 a${tx}.lst b${tx}.lst | awk -F '\t' '{if( NF == 2 ) {print substr($2,1,4)}}'`
set cnt = 0 
foreach s (`echo $nmtlst`)
    @ cnt = $cnt + 1
    grep $s $rmsf | awk -v cnt=$cnt '{printf("*SC %4d %s       %s\n",cnt, $1, substr($0,8))}' >> $logf
end
if ( $cnt > 0 ) echo " " >> $logf
set cnt = 0 
foreach s (`echo $cwulst`)
    @ cnt = $cnt + 1
    grep $s $rmsf | awk -v cnt=$cnt '{printf("*SC %4d       %s %s\n",cnt, $1, substr($0,8))}' >> $logf
end

\rm a${tx}.* b${tx}.* h${gpsw}${gpsd}.f.gdl h${gpsw}${gpsd}.f.glist

# Now run the globk solutions on the centers.
cd ../COM
\rm com${gpsw}${gpsd}.f.* >&! /dev/null 
# Weights here are sqrt(2) times each center to keep sigma ~correct
ls ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.[bf].gls | awk '{print $1 "  1.4"}' > ! com${gpsw}${gpsd}.f.gdl
ls ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.${ty}.gls | awk '{print $1 "  9.6"}' >> com${gpsw}${gpsd}.f.gdl
#ls ../USG_glbf/h${gpsw}${gpsd}_1200_usg.b.glx | awk '{print $1 "  1.4"}' >> com${gpsw}${gpsd}.f.gdl
###ls com${gpsw}${gpsd}.b.glb >> com${gpsw}${gpsd}.f.gdl
globk 6  com${gpsw}${gpsd}.f.prt com${gpsw}${gpsd}.f.log com${gpsw}${gpsd}.f.gdl ../tables/globk_rep.cmd >&! /dev/null

## Save the sinex file from the combinaed run
glbtosnx ../products +../tables/head.pbo com${gpsw}${gpsd}.f.glb     pbo${gpsw}${gpsd}.suppl_loose.snx.${ts}
glbtosnx ../products +../tables/head.pbo com${gpsw}${gpsd}.f.glb.CON pbo${gpsw}${gpsd}.suppl_nam08.snx.${ts}
\cp -p ../COM_snx/com${gpsw}${gpsd}.${yr}${mth}${dom}.f.rms ../products/pbo${gpsw}${gpsd}.suppl_nam08.rms.${ts}
\rm  com${gpsw}${gpsd}.f.sol com${gpsw}${gpsd}.f.glb.CON com${gpsw}${gpsd}.f.com
#
# Check for site coordinates that we do not have and those that do no match aprioiri
#set apfs = `grep '^ ' ../tables/globk_rep.cmd ../tables/glorg_rep.cmd | grep -i apr_file | egrep -v "NONE|@.apr" | awk '{print $3}'`
set apfs = `grep -i "APRIORI file   :"  ../COM/com${gpsw}${gpsd}.f.org | awk '{print $4}'`
#
sh_exglk -f com${gpsw}${gpsd}.f.org -pos t.pos.${ts}
set sites = `grep '^ ' t.pos.${ts} | grep -v '_X' | awk '{print substr($13,1,8)}'`
# Now check the quality of each site position.  
grep 'POS S' com${gpsw}${gpsd}.f.org  | awk '{print "*BC "substr($0,17)}' >> ../control/${logf}
set badout = 0
set badlist = ""
set nadd = 0
foreach s ( `echo $sites` )
#
    set s4 = `echo $s | awk '{print substr($1,1,4)}'`
#   See if this site is in apriori files.
#   Chi[1] 2-D (mm), Chi[2] dH mm; chi[3] = 2D sigma Normalized, chi[4] height normalized; chi[5] 3-D normalized
    set chi = `grep $s t.pos.${ts} | awk '{print sqrt(($3^2+$4^2)/2), sqrt($10^2), sqrt((($3/$7)^2+($4/$8)^2)/2), sqrt(($10/$12)^2), sqrt((($3/$7)^2+($4/$8)^2+($10/$12)^2)/3)}'` 
#
#   See if site is in apriori files
    set inapfs = `grep $s $apfs | wc -l`
    if( $inapfs > 0 ) then
#       Site is in aprori files; see if anomalous: more than 4-sigma from apriori
        set bad = `echo $chi[5] | awk '{if( $1 > 4 ) {print "1"} else {print "0"}}'`
        if ( $bad == 1 ) then
           if ( $badout == 0 ) then
              echo "*BC Sites with large position adjustments from combined solution" >> ../control/${logf}
              echo "*BC Num     Site     dE    +-      dN     +-    dH     +-      COM #    RMS    CWU #    RMS     NMT #    RMS " >> ../control/${logf}
           endif
           @ badout = $badout + 1; set badlist = `echo $badlist $s`
           echo $badout | awk '{printf("*BC %3d",$1)}' >> ../control/${logf}
           grep $s  t.pos.${ts} | awk '{printf(" %9s %6.1f %6.1f %6.1f %6.1f %6.1f %6.1f ",$13,$3,$7,$4,$8,$10,$12)}' >> ../control/${logf}
           grep $s4 $rmsf | awk '{printf(" %s",substr($0,6,48))}' >> ../control/${logf}  
           set innew = `grep '^ ' ../tables/PBO_new.apr | grep $s | wc -l`
           if( $innew > 0 ) then
              echo "Newer site" >> ../control/${logf}
           else
              echo "" >> ../control/${logf}
           endif
        endif
    else
#       Add site to Updated file
        set OK = `grep Apr. com${gpsw}${gpsd}.f.org | grep $s | awk '{if ( $12 < 0.01 ) {print substr($0,5)}}' | wc -c`
        if( $OK > 0 ) then 
            if ( $nadd == 0 ) then
                 echo "* Site added "`date` >> ../tables/PBO_new.apr 
            endif
            @ nadd++
            grep Apr. com${gpsw}${gpsd}.f.org | grep $s | awk '{if ( $12 < 0.01 ) {print substr($0,5)}}' >> ../tables/PBO_new.apr
        endif
    endif
end
\rm t.pos.${ts}
                
if( -e ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.f.gls ) then
    cd ../NMT
    \rm nmt${gpsw}${gpsd}.f.* >&! /dev/null
    ls ../NMT_glbf/h${gpsw}${gpsd}_1200_???.b.gls ../NMT_glbf/h${gpsw}${gpsd}_1200_nmt.f.gls | awk '{print $1 "  0.7"}' >! nmt${gpsw}${gpsd}.f.gdl
#   Allow for an original BSL finals run to which NMT will be added.
#    ls ../NMT/nmt${gpsw}${gpsd}.b.glb >> nmt${gpsw}${gpsd}.f.gdl

    globk 6  nmt${gpsw}${gpsd}.f.prt nmt${gpsw}${gpsd}.f.log nmt${gpsw}${gpsd}.f.gdl ../tables/globk_rep.cmd >&! /dev/null
# Save the sinex file from the combinaed run
    \cp -p ../NMT_snx/nmt${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx ../products/nmt${gpsw}${gpsd}.suppl_loose.snx.${ts}
    glbtosnx ../products +../tables/head.pbo nmt${gpsw}${gpsd}.f.glb.CON nmt${gpsw}${gpsd}.suppl_nam08.snx.${ts}
    \rm  nmt${gpsw}${gpsd}.f.sol nmt${gpsw}${gpsd}.f.glb.CON nmt${gpsw}${gpsd}.f.com
#
    sh_exglk -f nmt${gpsw}${gpsd}.f.org -pos t.pos.${ts}
    set sites = `grep '^ ' t.pos.${ts} | grep -v '_X' | awk '{print substr($13,1,8)}'`
# Now check the quality of each site position.  
    grep 'POS S' nmt${gpsw}${gpsd}.f.org  | awk '{print "*BB "substr($0,17)}' >> ../control/${logf}
    grep BAD  nmt${gpsw}${gpsd}.f.log | awk '{printf("*BB Gross Error %s dXYZ %10.3f %10.3f %10.3f m\n",$6,$10,$11,$12)}' >> ../control/${logf}
    set badout = 0
    foreach s ( `echo $sites` )
#
        set s4 = `echo $s | awk '{print substr($1,1,4)}'`
#       See if this site is in apriori files.
#       Chi[1] 2-D (mm), Chi[2] dH mm; chi[3] = 2D sigma Normalized, chi[4] height normalized; chi[5] 3-D normalized
        set chi = `grep $s t.pos.${ts} | awk '{print sqrt(($3^2+$4^2)/2), sqrt($10^2), sqrt((($3/$7)^2+($4/$8)^2)/2), sqrt(($10/$12)^2), sqrt((($3/$7)^2+($4/$8)^2+($10/$12)^2)/3)}'` 
#
#       See if site is in apriori files
        set bad = `echo $chi[5] | awk '{if( $1 > 4 ) {print "1"} else {print "0"}}'`
        if ( $bad == 1 ) then
           if ( $badout == 0 ) then
              echo "*BB Sites with large position adjustments from combined solution" >> ../control/${logf}
              echo "*BB Num     Site     dE    +-      dN      +-    dH     +-     COM #    RMS    CWU #    RMS     NMT #    RMS" >> ../control/${logf}
           endif
           @ badout = $badout + 1; set badlist = `echo $badlist $s`
           echo $badout | awk '{printf("*BB %3d",$1)}' >> ../control/${logf}
           grep $s  t.pos.${ts} | awk '{printf(" %9s %6.1f %6.1f %6.1f %6.1f %6.1f %6.1f ",$13,$3,$7,$4,$8,$10,$12)}' >> ../control/${logf}
           grep $s4 $rmsf | awk '{printf(" %s",substr($0,6,48))}' >> ../control/${logf}  
           set innew = `grep '^ ' ../tables/PBO_new.apr | grep $s | wc -l`
           if( $innew > 0 ) then
              echo "Newer site" >> ../control/${logf}
           else
              echo "" >> ../control/${logf}
           endif
        endif
    end
endif
                
\rm t.pos.${ts}

cd ../CWU
\rm cwu${gpsw}${gpsd}.f.* >&! /dev/null
ls ../CWU_glbf/h${gpsw}${gpsd}_1200_cwu.${ty}.gls | awk '{print $1 "  4.8"}'>! cwu${gpsw}${gpsd}.f.gdl
#ls cwu${gpsw}${gpsd}.b.glb >> cwu${gpsw}${gpsd}.f.gdl

globk 6  cwu${gpsw}${gpsd}.f.prt cwu${gpsw}${gpsd}.f.log cwu${gpsw}${gpsd}.f.gdl ../tables/globk_rep.cmd >&! /dev/null
# Save the sinex file from the combinaed run
\cp -p ../CWU_snx/CWU${gpsw}${gpsd}.${yr}${mth}${dom}.f.snx ../products/cwu${gpsw}${gpsd}.suppl_loose.snx.${ts}
glbtosnx ../products  +../tables/head.pbo cwu${gpsw}${gpsd}.f.glb.CON cwu${gpsw}${gpsd}.suppl_nam08.snx.${ts}
\rm cwu${gpsw}${gpsd}.f.sol cwu${gpsw}${gpsd}.f.glb.CON cwu${gpsw}${gpsd}.f.com
#
sh_exglk -f cwu${gpsw}${gpsd}.f.org -pos t.pos.${ts}
set sites = `grep '^ ' t.pos.${ts} | grep -v '_X' | awk '{print substr($13,1,8)}'`
# Now check the quality of each site position.  
grep 'POS S' cwu${gpsw}${gpsd}.f.org  | awk '{print "*BW "substr($0,17)}' >> ../control/${logf}
grep BAD  cwu${gpsw}${gpsd}.f.log | awk '{printf("*BW Gross Error %s dXYZ %10.3f %10.3f %10.3f m\n",$6,$10,$11,$12)}' >> ../control/${logf}
set badout = 0
foreach s ( `echo $sites` )
#
    set s4 = `echo $s | awk '{print substr($1,1,4)}'`
#   See if this site is in apriori files.
#   Chi[1] 2-D (mm), Chi[2] dH mm; chi[3] = 2D sigma Normalized, chi[4] height normalized; chi[5] 3-D normalized
    set chi = `grep $s t.pos.${ts} | awk '{print sqrt(($3^2+$4^2)/2), sqrt($10^2), sqrt((($3/$7)^2+($4/$8)^2)/2), sqrt(($10/$12)^2), sqrt((($3/$7)^2+($4/$8)^2+($10/$12)^2)/3)}'` 
#
#   See if site is in apriori files
    set bad = `echo $chi[5] | awk '{if( $1 > 4 ) {print "1"} else {print "0"}}'`
    if ( $bad == 1 ) then
       if ( $badout == 0 ) then
          echo "*BW Sites with large position adjustments from combined solution" >> ../control/${logf}
          echo "*BW Num     Site     dE    +-       dN      +-    dH     +-    COM #    RMS    CWU #    RMS     NMT #    RMS" >> ../control/${logf}
       endif
       @ badout = $badout + 1; set badlist = `echo $badlist $s`
       echo $badout | awk '{printf("*BW %3d",$1)}' >> ../control/${logf}
       grep $s  t.pos.${ts} | awk '{printf(" %9s %6.1f %6.1f %6.1f %6.1f %6.1f %6.1f ",$13,$3,$7,$4,$8,$10,$12)}' >> ../control/${logf}
       grep $s4 $rmsf | awk '{printf(" %s",substr($0,6,48))}' >> ../control/${logf}  
       set innew = `grep '^ ' ../tables/PBO_new.apr | grep $s | wc -l`
       if( $innew > 0 ) then
          echo "Newer site" >> ../control/${logf}
       else
          echo "" >> ../control/${logf}
       endif
    endif
end
                
\rm t.pos.${ts}
#
# Now see how all the bad sites compare
set badlist = `echo $badlist | awk '{for (i=1; i<=NF; i++) printf " %s\n", $i}' | sort -u`
foreach s (`echo $badlist`)
   grep "^  [ 123]" ../[CN]??/???${gpsw}${gpsd}.f.org | egrep -v 'coordinate|XYZ' | grep $s | awk '{print "*BA ",$0}' >> ../control/${logf}
   echo "*BA +++" >> ../control/${logf}
end

#### Send off the sinex products
if( $ldm == "Y" ) then 
   pushd ../products
   csh ../control/sh_gzip_ts ${ts}
   ssh -n ldm@everest.mit.edu "cd /net/chandler/raid9/tah/ACC_PBO/products; ~/bin/sh_pqinsert *.${ts}"
#    ssh -n ldm@everest.mit.edu "cd /net/everest/raid6/tah/PBO_products; ~/bin/sh_pqinsert *.${ts}"

#   csh ../control/sh_ftp_pbo $ts
   popd
endif

#### See if we will send summary
if( $mailto != "N" ) then
   pushd ../control
   csh sh_summary -f $logf -m $mailto
   popd
endif




 


